@@ -11,10 +11,8 @@
 #include "grib_accessor_class_codetable.h"
 #include <cctype>
 
-
-grib_accessor_class_codetable_t _grib_accessor_class_codetable("codetable");
-grib_accessor_class* grib_accessor_class_codetable = &_grib_accessor_class_codetable;
-
+grib_accessor_codetable_t _grib_accessor_codetable{};
+grib_accessor* grib_accessor_codetable = &_grib_accessor_codetable;
 
 #if GRIB_PTHREADS
 static pthread_once_t once    = PTHREAD_ONCE_INIT;
@@ -34,7 +32,7 @@ static omp_nest_lock_t mutex1;
 
 static void init_mutex()
 {
-    GRIB_OMP_CRITICAL(lock_grib_accessor_class_codetable_c)
+    GRIB_OMP_CRITICAL(lock_grib_accessor_codetable_c)
     {
         if (once == 0) {
             omp_init_nest_lock(&mutex1);
@@ -46,16 +44,17 @@ static void init_mutex()
 
 static int grib_load_codetable(grib_context* c, const char* filename, const char* recomposed_name, size_t size, grib_codetable* t);
 
-void grib_accessor_class_codetable_t::init(grib_accessor* a, const long len, grib_arguments* params)
+void grib_accessor_codetable_t::init(const long len, grib_arguments* params)
 {
-    grib_accessor_class_unsigned_t::init(a, len, params);
+    grib_accessor_unsigned_t::init(len, params);
 
-    int n                         = 0;
-    long new_len                  = len;
-    grib_handle* hand             = grib_handle_of_accessor(a);
-    grib_accessor_codetable_t* self = (grib_accessor_codetable_t*)a;
-    grib_action* act              = (grib_action*)(a->creator);
-    DEBUG_ASSERT(len == self->nbytes);
+    int n             = 0;
+    long new_len      = len;
+    grib_handle* hand = grib_handle_of_accessor(this);
+    grib_action* act  = (grib_action*)(creator_);
+    DEBUG_ASSERT(len == nbytes_);
+    table_        = NULL;
+    table_loaded_ = 0;
 
     if (new_len == 0) {
         /* ECC-485: When the codetable length is 0, it means we are passing
@@ -64,33 +63,33 @@ void grib_accessor_class_codetable_t::init(grib_accessor* a, const long len, gri
          */
         new_len = grib_arguments_get_long(hand, params, n++);
         if (new_len <= 0) {
-            grib_context_log(a->context, GRIB_LOG_FATAL, "%s: codetable length must be a positive integer", a->name);
+            grib_context_log(context_, GRIB_LOG_FATAL, "%s: codetable length must be a positive integer", name_);
         }
-        self->nbytes = new_len;
+        nbytes_ = new_len;
     }
 
-    self->tablename = grib_arguments_get_string(hand, params, n++);
-    if (self->tablename == NULL) {
-        grib_context_log(a->context, GRIB_LOG_FATAL, "%s: codetable table is invalid", a->name);
+    tablename_ = grib_arguments_get_string(hand, params, n++);
+    if (tablename_ == NULL) {
+        grib_context_log(context_, GRIB_LOG_FATAL, "%s: codetable table is invalid", name_);
     }
-    self->masterDir = grib_arguments_get_name(hand, params, n++); /* can be NULL */
-    self->localDir  = grib_arguments_get_name(hand, params, n++); /* can be NULL */
+    masterDir_ = grib_arguments_get_name(hand, params, n++); /* can be NULL */
+    localDir_  = grib_arguments_get_name(hand, params, n++); /* can be NULL */
 
-    /*if (a->flags & GRIB_ACCESSOR_FLAG_STRING_TYPE)
-    printf("-------- %s type string (%ld)\n",a->name,a->flags);*/
+    /*if (flags_ & GRIB_ACCESSOR_FLAG_STRING_TYPE)
+    printf("-------- %s type string (%ld)\n",a->name,flags_ );*/
 #ifdef DEBUG
-    if (a->flags & GRIB_ACCESSOR_FLAG_CAN_BE_MISSING) {
-        grib_context_log(a->context, GRIB_LOG_FATAL, "codetable '%s' has flag can_be_missing!", a->name);
+    if (flags_ & GRIB_ACCESSOR_FLAG_CAN_BE_MISSING) {
+        grib_context_log(context_, GRIB_LOG_FATAL, "codetable '%s' has flag can_be_missing!", name_);
         Assert(!"codetable with can_be_missing?");
     }
 #endif
 
-    if (a->flags & GRIB_ACCESSOR_FLAG_TRANSIENT) {
-        a->length = 0;
-        if (!a->vvalue)
-            a->vvalue = (grib_virtual_value*)grib_context_malloc_clear(a->context, sizeof(grib_virtual_value));
-        a->vvalue->type   = a->get_native_type();
-        a->vvalue->length = new_len;
+    if (flags_ & GRIB_ACCESSOR_FLAG_TRANSIENT) {
+        length_ = 0;
+        if (!vvalue_)
+            vvalue_ = (grib_virtual_value*)grib_context_malloc_clear(context_, sizeof(grib_virtual_value));
+        vvalue_->type   = get_native_type();
+        vvalue_->length = new_len;
         if (act->default_value != NULL) {
             const char* p = 0;
             size_t s_len  = 1;
@@ -103,29 +102,29 @@ void grib_accessor_class_codetable_t::init(grib_accessor* a, const long len, gri
             switch (type) {
                 case GRIB_TYPE_DOUBLE:
                     grib_expression_evaluate_double(hand, expression, &d);
-                    a->pack_double(&d, &s_len);
+                    pack_double(&d, &s_len);
                     break;
 
                 case GRIB_TYPE_LONG:
-                    grib_expression_evaluate_long(grib_handle_of_accessor(a), expression, &l);
-                    a->pack_long(&l, &s_len);
+                    grib_expression_evaluate_long(grib_handle_of_accessor(this), expression, &l);
+                    pack_long(&l, &s_len);
                     break;
 
                 default:
                     s_len = sizeof(tmp);
-                    p     = grib_expression_evaluate_string(grib_handle_of_accessor(a), expression, tmp, &s_len, &ret);
+                    p     = grib_expression_evaluate_string(grib_handle_of_accessor(this), expression, tmp, &s_len, &ret);
                     if (ret != GRIB_SUCCESS) {
-                        grib_context_log(a->context, GRIB_LOG_FATAL,
-                                         "Unable to evaluate %s as string", a->name);
+                        grib_context_log(context_, GRIB_LOG_FATAL,
+                                         "Unable to evaluate %s as string", name_);
                     }
                     s_len = strlen(p) + 1;
-                    pack_string(a, p, &s_len);
+                    pack_string(p, &s_len);
                     break;
             }
         }
     }
     else {
-        a->length = new_len;
+        length_ = new_len;
     }
 }
 
@@ -164,43 +163,43 @@ static void dump_codetable(grib_codetable* atable)
     }
 }
 #endif
-static grib_codetable* load_table(grib_accessor* a)
+
+grib_codetable* grib_accessor_codetable_t::load_table()
 {
-    grib_accessor_codetable_t* self = (grib_accessor_codetable_t*)a;
-    size_t size           = 0;
-    grib_handle* h        = ((grib_accessor*)self)->parent->h;
-    grib_context* c       = h->context;
-    grib_codetable* t     = NULL;
-    grib_codetable* next  = NULL;
-    char* filename        = 0;
-    char recomposed[1024] = {0,};
+    size_t size                     = 0;
+    grib_handle* h                  = parent_->h;
+    grib_context* c                 = h->context;
+    grib_codetable* t               = NULL;
+    grib_codetable* next            = NULL;
+    char* filename                  = 0;
+    char recomposed[1024]           = {0,};
     char localRecomposed[1024] = {0,};
     char* localFilename  = 0;
     char masterDir[1024] = {0,};
     char localDir[1024] = {0,};
     size_t len = 1024;
 
-    if (self->masterDir != NULL)
-        grib_get_string(h, self->masterDir, masterDir, &len);
+    if (masterDir_ != NULL)
+        grib_get_string(h, masterDir_, masterDir, &len);
 
     len = 1024;
-    if (self->localDir != NULL)
-        grib_get_string(h, self->localDir, localDir, &len);
+    if (localDir_ != NULL)
+        grib_get_string(h, localDir_, localDir, &len);
 
     if (*masterDir != 0) {
         char name[2048] = {0,};
-        snprintf(name, sizeof(name), "%s/%s", masterDir, self->tablename);
+        snprintf(name, sizeof(name), "%s/%s", masterDir, tablename_);
         grib_recompose_name(h, NULL, name, recomposed, 0);
         filename = grib_context_full_defs_path(c, recomposed);
     }
     else {
-        grib_recompose_name(h, NULL, self->tablename, recomposed, 0);
+        grib_recompose_name(h, NULL, tablename_, recomposed, 0);
         filename = grib_context_full_defs_path(c, recomposed);
     }
 
     if (*localDir != 0) {
         char localName[2048] = {0,};
-        snprintf(localName, sizeof(localName), "%s/%s", localDir, self->tablename);
+        snprintf(localName, sizeof(localName), "%s/%s", localDir, tablename_);
         grib_recompose_name(h, NULL, localName, localRecomposed, 0);
         localFilename = grib_context_full_defs_path(c, localRecomposed);
     }
@@ -208,7 +207,7 @@ static grib_codetable* load_table(grib_accessor* a)
     GRIB_MUTEX_INIT_ONCE(&once, &init_mutex);
     GRIB_MUTEX_LOCK(&mutex1); /* GRIB-930 */
 
-    /*printf("DBG %s: Look in cache: f=%s lf=%s (recomposed=%s)\n", self->att.name, filename, localFilename,recomposed);*/
+    /*printf("DBG %s: Look in cache: f=%s lf=%s (recomposed=%s)\n", att_ .name, filename, localFilename,recomposed);*/
     if (filename == NULL && localFilename == NULL) {
         t = NULL;
         goto the_end;
@@ -232,12 +231,12 @@ static grib_codetable* load_table(grib_accessor* a)
         next = next->next;
     }
 
-    if (a->flags & GRIB_ACCESSOR_FLAG_TRANSIENT) {
-        Assert(a->vvalue != NULL);
-        size = a->vvalue->length * 8;
+    if (flags_ & GRIB_ACCESSOR_FLAG_TRANSIENT) {
+        Assert(vvalue_ != NULL);
+        size = vvalue_->length * 8;
     }
     else {
-        size = ((grib_accessor*)self)->byte_count() * 8;
+        size = byte_count() * 8;
     }
 
     size = (1ULL << size); /* 2^size - 64bits */
@@ -421,34 +420,34 @@ void grib_codetable_delete(grib_context* c)
 
 int codes_codetable_get_contents_malloc(const grib_handle* h, const char* key, code_table_entry** entries, size_t* num_entries)
 {
-    long lvalue = 0;
-    size_t size = 1;
-    int err = 0;
+    long lvalue     = 0;
+    size_t size     = 1;
+    int err         = 0;
     grib_context* c = h->context;
 
     grib_accessor* aa = grib_find_accessor(h, key);
     if (!aa) return GRIB_NOT_FOUND;
 
-    if (!STR_EQUAL(aa->cclass->name, "codetable")) {
-        return GRIB_INVALID_ARGUMENT; // key is not a codetable
+    if (!STR_EQUAL(aa->class_name_, "codetable")) {
+        return GRIB_INVALID_ARGUMENT;  // key is not a codetable
     }
 
-    const grib_accessor_codetable_t* ca = (const grib_accessor_codetable_t*)aa; // could be dynamic_cast
+    const grib_accessor_codetable_t* ca = (const grib_accessor_codetable_t*)aa;  // could be dynamic_cast
 
     // Decode the key itself. This will either fetch it from the cache or place it there
     if ((err = aa->unpack_long(&lvalue, &size)) != GRIB_SUCCESS) {
         return err;
     }
 
-    const grib_codetable* table = ca->table;
+    const grib_codetable* table = ca->codetable();
     if (!table) return GRIB_INTERNAL_ERROR;
 
-    grib_codetable* cached_table = c->codetable; // Access the codetable cache
+    grib_codetable* cached_table = c->codetable;  // Access the codetable cache
     while (cached_table) {
         if (STR_EQUAL(table->recomposed_name[0], cached_table->recomposed_name[0])) {
             // Found a cache entry that matches the recomposed name of ours
             *num_entries = cached_table->size;
-            *entries = (code_table_entry*)calloc(cached_table->size, sizeof(code_table_entry));
+            *entries     = (code_table_entry*)calloc(cached_table->size, sizeof(code_table_entry));
             if (!*entries) {
                 return GRIB_OUT_OF_MEMORY;
             }
@@ -466,9 +465,9 @@ int codes_codetable_get_contents_malloc(const grib_handle* h, const char* key, c
 int codes_codetable_check_code_figure(const grib_handle* h, const char* key, long code_figure)
 {
     code_table_entry* entries = NULL;
-    size_t num_entries = 0;
-    int err = 0;
-    err = codes_codetable_get_contents_malloc(h, key, &entries, &num_entries);
+    size_t num_entries        = 0;
+    int err                   = 0;
+    err                       = codes_codetable_get_contents_malloc(h, key, &entries, &num_entries);
     if (err) return err;
 
     if (code_figure < 0 || (size_t)code_figure >= num_entries) {
@@ -488,13 +487,13 @@ cleanup:
 int codes_codetable_check_abbreviation(const grib_handle* h, const char* key, const char* abbreviation)
 {
     code_table_entry* entries = NULL;
-    size_t num_entries = 0;
-    int err = 0;
-    err = codes_codetable_get_contents_malloc(h, key, &entries, &num_entries);
+    size_t num_entries        = 0;
+    int err                   = 0;
+    err                       = codes_codetable_get_contents_malloc(h, key, &entries, &num_entries);
     if (err) return err;
 
     bool found = false;
-    for (size_t i=0; i<num_entries; ++i) {
+    for (size_t i = 0; i < num_entries; ++i) {
         const char* abbrev = entries[i].abbreviation;
         if (abbrev && STR_EQUAL(abbrev, abbreviation)) {
             found = true;
@@ -507,26 +506,25 @@ int codes_codetable_check_abbreviation(const grib_handle* h, const char* key, co
     return err;
 }
 
-void grib_accessor_class_codetable_t::dump(grib_accessor* a, grib_dumper* dumper)
+void grib_accessor_codetable_t::dump(grib_dumper* dumper)
 {
-    grib_accessor_codetable_t* self = (grib_accessor_codetable_t*)a;
     char comment[2048];
     grib_codetable* table;
 
     size_t llen = 1;
     long value;
 
-    if (!self->table_loaded) {
-        self->table        = load_table(a); /* may return NULL */
-        self->table_loaded = 1;
+    if (!table_loaded_) {
+        table_        = load_table(); /* may return NULL */
+        table_loaded_ = 1;
     }
-    table = self->table;
+    table = table_;
 
-    a->unpack_long(&value, &llen);
+    unpack_long(&value, &llen);
 
     if (value == GRIB_MISSING_LONG) {
-        if (a->length < 4) {
-            value = (1L << a->length) - 1;
+        if (length_ < 4) {
+            value = (1L << length_) - 1;
         }
     }
 
@@ -562,13 +560,12 @@ void grib_accessor_class_codetable_t::dump(grib_accessor* a, grib_dumper* dumper
     }
     strcat(comment, ") ");
 
-    grib_dump_long(dumper, a, comment);
+    grib_dump_long(dumper, this, comment);
 }
 
-int grib_accessor_class_codetable_t::unpack_string(grib_accessor* a, char* buffer, size_t* len)
+int grib_accessor_codetable_t::unpack_string(char* buffer, size_t* len)
 {
-    grib_accessor_codetable_t* self = (grib_accessor_codetable_t*)a;
-    grib_codetable* table         = NULL;
+    grib_codetable* table = NULL;
 
     size_t size = 1;
     long value;
@@ -576,14 +573,14 @@ int grib_accessor_class_codetable_t::unpack_string(grib_accessor* a, char* buffe
     char tmp[1024];
     size_t l = 0;
 
-    if ((err = a->unpack_long(&value, &size)) != GRIB_SUCCESS)
+    if ((err = unpack_long(&value, &size)) != GRIB_SUCCESS)
         return err;
 
-    if (!self->table_loaded) {
-        self->table        = load_table(a); /* may return NULL */
-        self->table_loaded = 1;
+    if (!table_loaded_) {
+        table_        = load_table(); /* may return NULL */
+        table_loaded_ = 1;
     }
-    table = self->table;
+    table = table_;
 
     if (table && (value >= 0) && (value < table->size) && table->entries[value].abbreviation) {
         strcpy(tmp, table->entries[value].abbreviation);
@@ -595,10 +592,9 @@ int grib_accessor_class_codetable_t::unpack_string(grib_accessor* a, char* buffe
     l = strlen(tmp) + 1;
 
     if (*len < l) {
-        const char* cclass_name = a->cclass->name;
-        grib_context_log(a->context, GRIB_LOG_ERROR,
+        grib_context_log(context_, GRIB_LOG_ERROR,
                          "%s: Buffer too small for %s. It is %zu bytes long (len=%zu)",
-                         cclass_name, a->name, l, *len);
+                         class_name_, name_, l, *len);
         *len = l;
         return GRIB_BUFFER_TOO_SMALL;
     }
@@ -609,7 +605,7 @@ int grib_accessor_class_codetable_t::unpack_string(grib_accessor* a, char* buffe
     return GRIB_SUCCESS;
 }
 
-int grib_accessor_class_codetable_t::value_count(grib_accessor* a, long* count)
+int grib_accessor_codetable_t::value_count(long* count)
 {
     *count = 1;
     return 0;
@@ -632,36 +628,35 @@ bool strings_equal(const char* s1, const char* s2, bool case_sensitive)
     return (strcmp_nocase(s1, s2) == 0);
 }
 
-int grib_accessor_class_codetable_t::pack_string(grib_accessor* a, const char* buffer, size_t* len)
+int grib_accessor_codetable_t::pack_string(const char* buffer, size_t* len)
 {
     long lValue = 0;
     Assert(buffer);
     if (is_number(buffer) && string_to_long(buffer, &lValue, 1) == GRIB_SUCCESS) {
         // ECC-1654: If value is a pure number, just pack as long
         size_t l = 1;
-        return a->pack_long(&lValue, &l);
+        return pack_long(&lValue, &l);
     }
 
     if (STR_EQUAL_NOCASE(buffer, "missing")) {
-        return pack_missing(a);
+        return pack_missing();
     }
 
-    grib_accessor_codetable_t* self = (grib_accessor_codetable_t*)a;
     grib_codetable* table = NULL;
-    long i = 0;
-    size_t size = 1;
+    long i                = 0;
+    size_t size           = 1;
 
-    if (!self->table_loaded) {
-        self->table        = load_table(a); /* may return NULL */
-        self->table_loaded = 1;
+    if (!table_loaded_) {
+        table_        = load_table(); /* may return NULL */
+        table_loaded_ = 1;
     }
-    table = self->table;
+    table = table_;
 
     if (!table)
         return GRIB_ENCODING_ERROR;
 
-    if (a->set) {
-        int err = grib_set_string(grib_handle_of_accessor(a), a->set, buffer, len);
+    if (set_) {
+        int err = grib_set_string(grib_handle_of_accessor(this), set_, buffer, len);
         if (err != 0)
             return err;
     }
@@ -669,48 +664,48 @@ int grib_accessor_class_codetable_t::pack_string(grib_accessor* a, const char* b
     // If the key has the "lowercase" flag set, then the string comparison
     // should ignore the case
     bool case_sensitive = true;
-    if (a->flags & GRIB_ACCESSOR_FLAG_LOWERCASE) case_sensitive = false;
+    if (flags_ & GRIB_ACCESSOR_FLAG_LOWERCASE) case_sensitive = false;
 
     for (i = 0; i < table->size; i++) {
         if (table->entries[i].abbreviation) {
             if (strings_equal(table->entries[i].abbreviation, buffer, case_sensitive)) {
-                return a->pack_long(&i, &size);
+                return pack_long(&i, &size);
             }
         }
     }
 
-    if (a->flags & GRIB_ACCESSOR_FLAG_NO_FAIL) {
-        grib_action* act = (grib_action*)(a->creator);
+    if (flags_ & GRIB_ACCESSOR_FLAG_NO_FAIL) {
+        grib_action* act = (grib_action*)(creator_);
         if (act->default_value != NULL) {
-            const char* p = 0;
-            size_t s_len  = 1;
-            long l = 0;
-            int ret = 0;
-            double d = 0;
+            const char* p  = 0;
+            size_t s_len   = 1;
+            long l         = 0;
+            int ret        = 0;
+            double d       = 0;
             char tmp[1024] = {0,};
-            grib_expression* expression = grib_arguments_get_expression(grib_handle_of_accessor(a), act->default_value, 0);
-            int type                    = grib_expression_native_type(grib_handle_of_accessor(a), expression);
+            grib_expression* expression = grib_arguments_get_expression(grib_handle_of_accessor(this), act->default_value, 0);
+            int type                    = grib_expression_native_type(grib_handle_of_accessor(this), expression);
             switch (type) {
                 case GRIB_TYPE_DOUBLE:
-                    grib_expression_evaluate_double(grib_handle_of_accessor(a), expression, &d);
-                    a->pack_double(&d, &s_len);
+                    grib_expression_evaluate_double(grib_handle_of_accessor(this), expression, &d);
+                    pack_double(&d, &s_len);
                     break;
 
                 case GRIB_TYPE_LONG:
-                    grib_expression_evaluate_long(grib_handle_of_accessor(a), expression, &l);
-                    a->pack_long(&l, &s_len);
+                    grib_expression_evaluate_long(grib_handle_of_accessor(this), expression, &l);
+                    pack_long(&l, &s_len);
                     break;
 
                 default:
                     s_len = sizeof(tmp);
-                    p     = grib_expression_evaluate_string(grib_handle_of_accessor(a), expression, tmp, &s_len, &ret);
+                    p     = grib_expression_evaluate_string(grib_handle_of_accessor(this), expression, tmp, &s_len, &ret);
                     if (ret != GRIB_SUCCESS) {
-                        grib_context_log(a->context, GRIB_LOG_ERROR,
-                                         "%s: Unable to evaluate default value of %s as string expression", __func__, a->name);
+                        grib_context_log(context_, GRIB_LOG_ERROR,
+                                         "%s: Unable to evaluate default value of %s as string expression", __func__, name_);
                         return ret;
                     }
                     s_len = strlen(p) + 1;
-                    pack_string(a, p, &s_len);
+                    pack_string(p, &s_len);
                     break;
             }
             return GRIB_SUCCESS;
@@ -721,10 +716,10 @@ int grib_accessor_class_codetable_t::pack_string(grib_accessor* a, const char* b
     for (i = 0; i < table->size; i++) {
         if (table->entries[i].abbreviation) {
             if (strcmp_nocase(table->entries[i].abbreviation, buffer) == 0) {
-                grib_context_log(a->context, GRIB_LOG_ERROR,
+                grib_context_log(context_, GRIB_LOG_ERROR,
                                  "%s: No such code table entry: '%s' "
                                  "(Did you mean '%s'?)",
-                                 a->name, buffer, table->entries[i].abbreviation);
+                                 name_, buffer, table->entries[i].abbreviation);
             }
         }
     }
@@ -732,124 +727,122 @@ int grib_accessor_class_codetable_t::pack_string(grib_accessor* a, const char* b
     return GRIB_ENCODING_ERROR;
 }
 
-int grib_accessor_class_codetable_t::pack_expression(grib_accessor* a, grib_expression* e)
+int grib_accessor_codetable_t::pack_expression(grib_expression* e)
 {
     const char* cval  = NULL;
     int ret           = 0;
     long lval         = 0;
     size_t len        = 1;
-    grib_handle* hand = grib_handle_of_accessor(a);
+    grib_handle* hand = grib_handle_of_accessor(this);
 
     if (strcmp(e->cclass->name, "long") == 0) {
         grib_expression_evaluate_long(hand, e, &lval); /* TODO: check return value */
-        //if (hand->context->debug) printf("ECCODES DEBUG grib_accessor_class_codetable::pack_expression %s %ld\n", a->name,lval);
-        ret = a->pack_long(&lval, &len);
+        // if (hand->context->debug) printf("ECCODES DEBUG grib_accessor_codetable::pack_expression %s %ld\n", name_ ,lval);
+        ret = pack_long(&lval, &len);
     }
     else {
         char tmp[1024];
         len  = sizeof(tmp);
         cval = grib_expression_evaluate_string(hand, e, tmp, &len, &ret);
         if (ret != GRIB_SUCCESS) {
-            grib_context_log(a->context, GRIB_LOG_ERROR,
-                "grib_accessor_codetable.%s: Unable to evaluate string %s to be set in %s",
-                __func__, grib_expression_get_name(e), a->name);
+            grib_context_log(context_, GRIB_LOG_ERROR,
+                             "grib_accessor_codetable.%s: Unable to evaluate string %s to be set in %s",
+                             __func__, grib_expression_get_name(e), name_);
             return ret;
         }
         len = strlen(cval) + 1;
-        //if (hand->context->debug)
-        //    printf("ECCODES DEBUG grib_accessor_class_codetable::pack_expression %s %s\n", a->name, cval);
-        ret = a->pack_string(cval, &len);
+        // if (hand->context->debug)
+        //     printf("ECCODES DEBUG grib_accessor_codetable::pack_expression %s %s\n", name_ , cval);
+        ret = pack_string(cval, &len);
     }
     return ret;
 }
 
-void grib_accessor_class_codetable_t::destroy(grib_context* context, grib_accessor* a)
+void grib_accessor_codetable_t::destroy(grib_context* context)
 {
-    if (a->vvalue != NULL) {
-        grib_context_free(context, a->vvalue);
-        a->vvalue = NULL;
+    if (vvalue_ != NULL) {
+        grib_context_free(context, vvalue_);
+        vvalue_ = NULL;
     }
-    grib_accessor_class_unsigned_t::destroy(context, a);
+    grib_accessor_unsigned_t::destroy(context);
 }
 
-int grib_accessor_class_codetable_t::get_native_type(grib_accessor* a)
+long grib_accessor_codetable_t::get_native_type()
 {
     int type = GRIB_TYPE_LONG;
     /*printf("---------- %s flags=%ld GRIB_ACCESSOR_FLAG_STRING_TYPE=%d\n",
-         a->name,a->flags,GRIB_ACCESSOR_FLAG_STRING_TYPE);*/
-    if (a->flags & GRIB_ACCESSOR_FLAG_STRING_TYPE)
+         a->name,flags_ ,GRIB_ACCESSOR_FLAG_STRING_TYPE);*/
+    if (flags_ & GRIB_ACCESSOR_FLAG_STRING_TYPE)
         type = GRIB_TYPE_STRING;
     return type;
 }
 
-int grib_accessor_class_codetable_t::unpack_long(grib_accessor* a, long* val, size_t* len)
+int grib_accessor_codetable_t::unpack_long(long* val, size_t* len)
 {
-    grib_accessor_codetable_t* self = (grib_accessor_codetable_t*)a;
     long rlen = 0, i = 0;
-    long pos = a->offset * 8;
+    long pos          = offset_ * 8;
     grib_handle* hand = NULL;
 
 #ifdef DEBUG
     {
-        int err = a->value_count(&rlen);
+        int err = value_count(&rlen);
         Assert(!err);
         Assert(rlen == 1);
     }
 #endif
     rlen = 1; /* ECC-480 Performance: avoid func call overhead of grib_value_count */
 
-    if (!self->table_loaded) {
-        self->table        = load_table(a); /* may return NULL */
-        self->table_loaded = 1;
+    if (!table_loaded_) {
+        table_        = load_table(); /* may return NULL */
+        table_loaded_ = 1;
     }
 
     if (*len < rlen) {
-        grib_context_log(a->context, GRIB_LOG_ERROR, "Wrong size (%lu) for %s, it contains %ld values",
-                *len, a->name, rlen);
+        grib_context_log(context_, GRIB_LOG_ERROR, "Wrong size (%lu) for %s, it contains %ld values",
+                         *len, name_, rlen);
         *len = 0;
         return GRIB_ARRAY_TOO_SMALL;
     }
 
-    if (a->flags & GRIB_ACCESSOR_FLAG_TRANSIENT) {
-        *val = a->vvalue->lval;
+    if (flags_ & GRIB_ACCESSOR_FLAG_TRANSIENT) {
+        *val = vvalue_->lval;
         *len = 1;
         return GRIB_SUCCESS;
     }
 
     /* ECC-480 Performance: inline the grib_handle_of_accessor here to reduce func call overhead */
-    if (a->parent == NULL)
-        hand = a->h;
+    if (parent_ == NULL)
+        hand = h_;
     else
-        hand = a->parent->h;
+        hand = parent_->h;
 
     for (i = 0; i < rlen; i++) {
-        val[i] = (long)grib_decode_unsigned_long(hand->buffer->data, &pos, self->nbytes * 8);
+        val[i] = (long)grib_decode_unsigned_long(hand->buffer->data, &pos, nbytes_ * 8);
     }
 
     *len = rlen;
     return GRIB_SUCCESS;
 }
 
-int grib_accessor_class_codetable_t::pack_missing(grib_accessor* a)
+int grib_accessor_codetable_t::pack_missing()
 {
     // Many of the code tables do have a 'Missing' entry (all bits = 1)
     // So it is more user-friendly to allow setting codetable keys to
     // missing. For tables that do not have such an entry, an error is issued
-    grib_accessor_codetable_t* self = (grib_accessor_codetable_t*)a;
-    grib_handle* h = grib_handle_of_accessor(a);
+    grib_handle* h = grib_handle_of_accessor(this);
 
-    const long nbytes = a->length;
-    const long nbits = nbytes*8;
-    const long maxVal = (1<<nbits) - 1;
+    const long nbytes = length_;
+    const long nbits  = nbytes * 8;
+    const long maxVal = (1 << nbits) - 1;
 
-    int err = codes_codetable_check_code_figure(h, a->name, maxVal);
+    int err = codes_codetable_check_code_figure(h, name_, maxVal);
     if (!err) {
         size_t l = 1;
-        return a->pack_long(&maxVal, &l);
+        return pack_long(&maxVal, &l);
     }
 
-    grib_context_log(a->context, GRIB_LOG_ERROR, "There is no 'missing' entry in Code Table %s (%s)",
-            self->tablename, grib_get_error_message(err));
+    grib_context_log(context_, GRIB_LOG_ERROR, "There is no 'missing' entry in Code Table %s (%s)",
+                     tablename_, grib_get_error_message(err));
 
     return err;
 }
