@@ -15,20 +15,17 @@
 class grib_accessor_data_secondary_bitmap_t : public grib_accessor_gen_t
 {
 public:
-    /* Members defined in data_secondary_bitmap */
-    const char*  primary_bitmap;
-    const char*  secondary_bitmap;
-    const char*  missing_value;
-    const char*  expand_by;
-};
-
-class grib_accessor_class_data_secondary_bitmap_t : public grib_accessor_class_gen_t
-{
-public:
-    grib_accessor_class_data_secondary_bitmap_t(const char* name) : grib_accessor_class_gen_t(name) {}
+    grib_accessor_data_secondary_bitmap_t() :
+        grib_accessor_gen_t() { class_name_ = "data_secondary_bitmap"; }
     // grib_accessor* create_empty_accessor() override { return new grib_accessor_data_secondary_bitmap_t{}; }
-    int get_native_type(grib_accessor*) override;
-    int unpack_double(grib_accessor*, double* val, size_t* len) override;
-    void dump(grib_accessor*, grib_dumper*) override;
-    void init(grib_accessor*, const long, grib_arguments*) override;
+    long get_native_type() override;
+    int unpack_double(double* val, size_t* len) override;
+    void dump(grib_dumper*) override;
+    void init(const long, grib_arguments*) override;
+
+protected:
+    const char* primary_bitmap_ = nullptr;
+    const char* secondary_bitmap_ = nullptr;
+    const char* missing_value_ = nullptr;
+    const char* expand_by_ = nullptr;
 };
