@@ -1,4 +1,3 @@
-
 /*
  * (C) Copyright 2005- ECMWF.
  *
@@ -14,43 +13,41 @@
 #include "step_utilities.h"
 #include <stdexcept>
 
-grib_accessor_class_g2end_step_t _grib_accessor_class_g2end_step{ "g2end_step" };
-grib_accessor_class* grib_accessor_class_g2end_step = &_grib_accessor_class_g2end_step;
+grib_accessor_g2end_step_t _grib_accessor_g2end_step{};
+grib_accessor* grib_accessor_g2end_step = &_grib_accessor_g2end_step;
 
-
-void grib_accessor_class_g2end_step_t::init(grib_accessor* a, const long l, grib_arguments* c)
+void grib_accessor_g2end_step_t::init(const long l, grib_arguments* c)
 {
-    grib_accessor_class_long_t::init(a, l, c);
-    grib_accessor_g2end_step_t* self = (grib_accessor_g2end_step_t*)a;
-    int n                            = 0;
-    grib_handle* h                   = grib_handle_of_accessor(a);
+    grib_accessor_long_t::init(l, c);
+    int n          = 0;
+    grib_handle* h = grib_handle_of_accessor(this);
 
-    self->start_step_value = grib_arguments_get_name(h, c, n++);
-    self->step_units       = grib_arguments_get_name(h, c, n++);
+    start_step_value_ = grib_arguments_get_name(h, c, n++);
+    step_units_       = grib_arguments_get_name(h, c, n++);
 
-    self->year   = grib_arguments_get_name(h, c, n++);
-    self->month  = grib_arguments_get_name(h, c, n++);
-    self->day    = grib_arguments_get_name(h, c, n++);
-    self->hour   = grib_arguments_get_name(h, c, n++);
-    self->minute = grib_arguments_get_name(h, c, n++);
-    self->second = grib_arguments_get_name(h, c, n++);
+    year_   = grib_arguments_get_name(h, c, n++);
+    month_  = grib_arguments_get_name(h, c, n++);
+    day_    = grib_arguments_get_name(h, c, n++);
+    hour_   = grib_arguments_get_name(h, c, n++);
+    minute_ = grib_arguments_get_name(h, c, n++);
+    second_ = grib_arguments_get_name(h, c, n++);
 
-    self->year_of_end_of_interval   = grib_arguments_get_name(h, c, n++);
-    self->month_of_end_of_interval  = grib_arguments_get_name(h, c, n++);
-    self->day_of_end_of_interval    = grib_arguments_get_name(h, c, n++);
-    self->hour_of_end_of_interval   = grib_arguments_get_name(h, c, n++);
-    self->minute_of_end_of_interval = grib_arguments_get_name(h, c, n++);
-    self->second_of_end_of_interval = grib_arguments_get_name(h, c, n++);
+    year_of_end_of_interval_   = grib_arguments_get_name(h, c, n++);
+    month_of_end_of_interval_  = grib_arguments_get_name(h, c, n++);
+    day_of_end_of_interval_    = grib_arguments_get_name(h, c, n++);
+    hour_of_end_of_interval_   = grib_arguments_get_name(h, c, n++);
+    minute_of_end_of_interval_ = grib_arguments_get_name(h, c, n++);
+    second_of_end_of_interval_ = grib_arguments_get_name(h, c, n++);
 
-    self->time_range_unit     = grib_arguments_get_name(h, c, n++);
-    self->time_range_value    = grib_arguments_get_name(h, c, n++);
-    self->typeOfTimeIncrement = grib_arguments_get_name(h, c, n++);
-    self->numberOfTimeRanges  = grib_arguments_get_name(h, c, n++);
+    time_range_unit_     = grib_arguments_get_name(h, c, n++);
+    time_range_value_    = grib_arguments_get_name(h, c, n++);
+    typeOfTimeIncrement_ = grib_arguments_get_name(h, c, n++);
+    numberOfTimeRanges_  = grib_arguments_get_name(h, c, n++);
 }
 
-void grib_accessor_class_g2end_step_t::dump(grib_accessor* a, grib_dumper* dumper)
+void grib_accessor_g2end_step_t::dump(grib_dumper* dumper)
 {
-    grib_dump_double(dumper, a, NULL);
+    grib_dump_double(dumper, this, NULL);
 }
 
 // See GRIB-488
@@ -94,27 +91,26 @@ static int convert_time_range_long_(
     return GRIB_SUCCESS;
 }
 
-static int unpack_one_time_range_long_(grib_accessor* a, long* val, size_t* len)
+int grib_accessor_g2end_step_t::unpack_one_time_range_long_(long* val, size_t* len)
 {
-    grib_accessor_g2end_step_t* self = (grib_accessor_g2end_step_t*)a;
-    int err                          = 0;
+    int err = 0;
     long start_step_value;
     long step_units;
     long time_range_unit;
     long time_range_value, typeOfTimeIncrement;
     int add_time_range = 1; /* whether we add lengthOfTimeRange */
 
-    grib_handle* h = grib_handle_of_accessor(a);
+    grib_handle* h = grib_handle_of_accessor(this);
 
-    if ((err = grib_get_long_internal(h, self->start_step_value, &start_step_value)))
+    if ((err = grib_get_long_internal(h, start_step_value_, &start_step_value)))
         return err;
-    if ((err = grib_get_long_internal(h, self->step_units, &step_units)))
+    if ((err = grib_get_long_internal(h, step_units_, &step_units)))
         return err;
-    if ((err = grib_get_long_internal(h, self->time_range_unit, &time_range_unit)))
+    if ((err = grib_get_long_internal(h, time_range_unit_, &time_range_unit)))
         return err;
-    if ((err = grib_get_long_internal(h, self->time_range_value, &time_range_value)))
+    if ((err = grib_get_long_internal(h, time_range_value_, &time_range_value)))
         return err;
-    if ((err = grib_get_long_internal(h, self->typeOfTimeIncrement, &typeOfTimeIncrement)))
+    if ((err = grib_get_long_internal(h, typeOfTimeIncrement_, &typeOfTimeIncrement)))
         return err;
 
     err = convert_time_range_long_(h, step_units, time_range_unit, &time_range_value);
@@ -143,9 +139,8 @@ static int unpack_one_time_range_long_(grib_accessor* a, long* val, size_t* len)
     return GRIB_SUCCESS;
 }
 
-static int unpack_one_time_range_double_(grib_accessor* a, double* val, size_t* len)
+int grib_accessor_g2end_step_t::unpack_one_time_range_double_(double* val, size_t* len)
 {
-    grib_accessor_g2end_step_t* self = (grib_accessor_g2end_step_t*)a;
     int err                          = 0;
     double start_step_value;
     long start_step_unit;
@@ -155,19 +150,19 @@ static int unpack_one_time_range_double_(grib_accessor* a, double* val, size_t*
     long typeOfTimeIncrement;
     int add_time_range = 1; /* whether we add lengthOfTimeRange */
 
-    grib_handle* h = grib_handle_of_accessor(a);
+    grib_handle* h = grib_handle_of_accessor(this);
 
-    if ((err = grib_get_double_internal(h, self->start_step_value, &start_step_value)))
+    if ((err = grib_get_double_internal(h, start_step_value_, &start_step_value)))
         return err;
     if ((err = grib_get_long_internal(h, "startStepUnit", &start_step_unit)))
         return err;
-    if ((err = grib_get_long_internal(h, self->step_units, &step_units)))
+    if ((err = grib_get_long_internal(h, step_units_, &step_units)))
         return err;
-    if ((err = grib_get_long_internal(h, self->time_range_unit, &time_range_unit)))
+    if ((err = grib_get_long_internal(h, time_range_unit_, &time_range_unit)))
         return err;
-    if ((err = grib_get_double_internal(h, self->time_range_value, &time_range_value)))
+    if ((err = grib_get_double_internal(h, time_range_value_, &time_range_value)))
         return err;
-    if ((err = grib_get_long_internal(h, self->typeOfTimeIncrement, &typeOfTimeIncrement)))
+    if ((err = grib_get_long_internal(h, typeOfTimeIncrement_, &typeOfTimeIncrement)))
         return err;
 
     eccodes::Step start_step{ start_step_value, start_step_unit };
@@ -196,11 +191,10 @@ static int unpack_one_time_range_double_(grib_accessor* a, double* val, size_t*
 }
 
 #define MAX_NUM_TIME_RANGES 16 /* maximum number of time range specifications */
-static int unpack_multiple_time_ranges_long_(grib_accessor* a, long* val, size_t* len)
+int grib_accessor_g2end_step_t::unpack_multiple_time_ranges_long_(long* val, size_t* len)
 {
-    grib_accessor_g2end_step_t* self = (grib_accessor_g2end_step_t*)a;
     int i = 0, err = 0;
-    grib_handle* h         = grib_handle_of_accessor(a);
+    grib_handle* h          = grib_handle_of_accessor(this);
     long numberOfTimeRanges = 0, step_units = 0, start_step_value = 0;
 
     size_t count                                      = 0;
@@ -214,11 +208,11 @@ static int unpack_multiple_time_ranges_long_(grib_accessor* a, long* val, size_t
         0,
     };
 
-    if ((err = grib_get_long_internal(h, self->start_step_value, &start_step_value)))
+    if ((err = grib_get_long_internal(h, start_step_value_, &start_step_value)))
         return err;
-    if ((err = grib_get_long_internal(h, self->step_units, &step_units)))
+    if ((err = grib_get_long_internal(h, step_units_, &step_units)))
         return err;
-    if ((err = grib_get_long_internal(h, self->numberOfTimeRanges, &numberOfTimeRanges)))
+    if ((err = grib_get_long_internal(h, numberOfTimeRanges_, &numberOfTimeRanges)))
         return err;
     if (numberOfTimeRanges > MAX_NUM_TIME_RANGES) {
         grib_context_log(h->context, GRIB_LOG_ERROR, "Too many time range specifications!");
@@ -227,11 +221,11 @@ static int unpack_multiple_time_ranges_long_(grib_accessor* a, long* val, size_t
 
     count = numberOfTimeRanges;
     /* Get the arrays for the N time ranges */
-    if ((err = grib_get_long_array(h, self->typeOfTimeIncrement, arr_typeOfTimeIncrement, &count)))
+    if ((err = grib_get_long_array(h, typeOfTimeIncrement_, arr_typeOfTimeIncrement, &count)))
         return err;
-    if ((err = grib_get_long_array(h, self->time_range_unit, arr_coded_unit, &count)))
+    if ((err = grib_get_long_array(h, time_range_unit_, arr_coded_unit, &count)))
         return err;
-    if ((err = grib_get_long_array(h, self->time_range_value, arr_coded_time_range, &count)))
+    if ((err = grib_get_long_array(h, time_range_value_, arr_coded_time_range, &count)))
         return err;
 
     /* Look in the array of typeOfTimeIncrements for first entry whose typeOfTimeIncrement == 2 */
@@ -255,11 +249,10 @@ static int unpack_multiple_time_ranges_long_(grib_accessor* a, long* val, size_t
     return GRIB_DECODING_ERROR;
 }
 
-static int unpack_multiple_time_ranges_double_(grib_accessor* a, double* val, size_t* len)
+int grib_accessor_g2end_step_t::unpack_multiple_time_ranges_double_(double* val, size_t* len)
 {
-    grib_accessor_g2end_step_t* self = (grib_accessor_g2end_step_t*)a;
     int i = 0, err = 0;
-    grib_handle* h          = grib_handle_of_accessor(a);
+    grib_handle* h          = grib_handle_of_accessor(this);
     long numberOfTimeRanges = 0;
     long step_units         = 0;
     long start_step_value   = 0;
@@ -276,17 +269,17 @@ static int unpack_multiple_time_ranges_double_(grib_accessor* a, double* val, si
         0,
     };
 
-    if ((err = grib_get_long_internal(h, self->start_step_value, &start_step_value)))
+    if ((err = grib_get_long_internal(h, start_step_value_, &start_step_value)))
         return err;
     if ((err = grib_get_long_internal(h, "startStepUnit", &start_step_unit)))
         return err;
 
     eccodes::Step start_step{ start_step_value, start_step_unit };
 
-    if ((err = grib_get_long_internal(h, self->step_units, &step_units)))
+    if ((err = grib_get_long_internal(h, step_units_, &step_units)))
         return err;
 
-    if ((err = grib_get_long_internal(h, self->numberOfTimeRanges, &numberOfTimeRanges)))
+    if ((err = grib_get_long_internal(h, numberOfTimeRanges_, &numberOfTimeRanges)))
         return err;
     if (numberOfTimeRanges > MAX_NUM_TIME_RANGES) {
         grib_context_log(h->context, GRIB_LOG_ERROR, "Too many time range specifications!");
@@ -295,11 +288,11 @@ static int unpack_multiple_time_ranges_double_(grib_accessor* a, double* val, si
 
     count = numberOfTimeRanges;
     /* Get the arrays for the N time ranges */
-    if ((err = grib_get_long_array(h, self->typeOfTimeIncrement, arr_typeOfTimeIncrement, &count)))
+    if ((err = grib_get_long_array(h, typeOfTimeIncrement_, arr_typeOfTimeIncrement, &count)))
         return err;
-    if ((err = grib_get_long_array(h, self->time_range_unit, arr_coded_unit, &count)))
+    if ((err = grib_get_long_array(h, time_range_unit_, arr_coded_unit, &count)))
         return err;
-    if ((err = grib_get_long_array(h, self->time_range_value, arr_coded_time_range, &count)))
+    if ((err = grib_get_long_array(h, time_range_value_, arr_coded_time_range, &count)))
         return err;
 
     /* Look in the array of typeOfTimeIncrements for first entry whose typeOfTimeIncrement == 2 */
@@ -309,7 +302,7 @@ static int unpack_multiple_time_ranges_double_(grib_accessor* a, double* val, si
             long the_coded_unit       = arr_coded_unit[i];
             long the_coded_time_range = arr_coded_time_range[i];
 
-            eccodes::Step time_range{the_coded_time_range, the_coded_unit};
+            eccodes::Step time_range{ the_coded_time_range, the_coded_unit };
             *val = (start_step + time_range).value<double>(eccodes::Unit(step_units));
 
             return GRIB_SUCCESS;
@@ -322,41 +315,40 @@ static int unpack_multiple_time_ranges_double_(grib_accessor* a, double* val, si
 }
 
 // For the old implementation of unpack_long, see
-//  src/deprecated/grib_accessor_class_g2end_step.unpack_long.cc
+//  src/deprecated/grib_accessor_g2end_step.unpack_long.cc
 //
-int grib_accessor_class_g2end_step_t::unpack_long(grib_accessor* a, long* val, size_t* len)
+int grib_accessor_g2end_step_t::unpack_long(long* val, size_t* len)
 {
-    grib_accessor_g2end_step_t* self = (grib_accessor_g2end_step_t*)a;
-    grib_handle* h                   = grib_handle_of_accessor(a);
-    int ret                          = 0;
-    long start_step_value = 0;
-    long start_step_unit = 0;
+    grib_handle* h          = grib_handle_of_accessor(this);
+    int ret                 = 0;
+    long start_step_value   = 0;
+    long start_step_unit    = 0;
     long numberOfTimeRanges = 0;
 
-    if ((ret = grib_get_long_internal(h, self->start_step_value, &start_step_value)))
+    if ((ret = grib_get_long_internal(h, start_step_value_, &start_step_value)))
         return ret;
     if ((ret = grib_get_long_internal(h, "startStepUnit", &start_step_unit)))
         return ret;
 
     /* point in time */
-    if (self->year == NULL) {
+    if (year_ == NULL) {
         *val = start_step_value;
         if ((ret = grib_set_long_internal(h, "endStepUnit", start_step_unit)))
             return ret;
         return 0;
     }
 
-    Assert(self->numberOfTimeRanges);
-    if ((ret = grib_get_long_internal(h, self->numberOfTimeRanges, &numberOfTimeRanges)))
+    Assert(numberOfTimeRanges_);
+    if ((ret = grib_get_long_internal(h, numberOfTimeRanges_, &numberOfTimeRanges)))
         return ret;
     Assert(numberOfTimeRanges == 1 || numberOfTimeRanges == 2);
 
     try {
         if (numberOfTimeRanges == 1) {
-            ret = unpack_one_time_range_long_(a, val, len);
+            ret = unpack_one_time_range_long_(val, len);
         }
         else {
-            ret = unpack_multiple_time_ranges_long_(a, val, len);
+            ret = unpack_multiple_time_ranges_long_(val, len);
         }
     }
     catch (std::exception& e) {
@@ -367,39 +359,38 @@ int grib_accessor_class_g2end_step_t::unpack_long(grib_accessor* a, long* val, s
     return ret;
 }
 
-int grib_accessor_class_g2end_step_t::unpack_double(grib_accessor* a, double* val, size_t* len)
+int grib_accessor_g2end_step_t::unpack_double(double* val, size_t* len)
 {
-    grib_accessor_g2end_step_t* self = (grib_accessor_g2end_step_t*)a;
-    grib_handle* h                   = grib_handle_of_accessor(a);
-    int ret                          = 0;
+    grib_handle* h = grib_handle_of_accessor(this);
+    int ret        = 0;
     long start_step_value;
     long start_step_unit;
     long numberOfTimeRanges;
 
-    if ((ret = grib_get_long_internal(h, self->start_step_value, &start_step_value)))
+    if ((ret = grib_get_long_internal(h, start_step_value_, &start_step_value)))
         return ret;
     if ((ret = grib_get_long_internal(h, "startStepUnit", &start_step_unit)))
         return ret;
 
     /* point in time */
-    if (self->year == NULL) {
+    if (year_ == NULL) {
         *val = start_step_value;
         if ((ret = grib_set_long_internal(h, "endStepUnit", start_step_unit)))
             return ret;
         return 0;
     }
 
-    Assert(self->numberOfTimeRanges);
-    if ((ret = grib_get_long_internal(h, self->numberOfTimeRanges, &numberOfTimeRanges)))
+    Assert(numberOfTimeRanges_);
+    if ((ret = grib_get_long_internal(h, numberOfTimeRanges_, &numberOfTimeRanges)))
         return ret;
     Assert(numberOfTimeRanges == 1 || numberOfTimeRanges == 2);
 
     try {
         if (numberOfTimeRanges == 1) {
-            ret = unpack_one_time_range_double_(a, val, len);
+            ret = unpack_one_time_range_double_(val, len);
         }
         else {
-            ret = unpack_multiple_time_ranges_double_(a, val, len);
+            ret = unpack_multiple_time_ranges_double_(val, len);
         }
     }
     catch (std::exception& e) {
@@ -410,10 +401,9 @@ int grib_accessor_class_g2end_step_t::unpack_double(grib_accessor* a, double* va
     return ret;
 }
 
-static int pack_long_(grib_accessor* a, const long end_step_value, const long end_step_unit)
+int grib_accessor_g2end_step_t::pack_long_(const long end_step_value, const long end_step_unit)
 {
-    grib_accessor_g2end_step_t* self = (grib_accessor_g2end_step_t*)a;
-    grib_handle* h = grib_handle_of_accessor(a);
+    grib_handle* h = grib_handle_of_accessor(this);
     int err = 0;
 
     long year;
@@ -435,34 +425,34 @@ static int pack_long_(grib_accessor* a, const long end_step_value, const long en
     long typeOfTimeIncrement;
 
     double dend, dstep;
-    const int show_units_for_hours = a->context->grib_hourly_steps_with_units;
+    const int show_units_for_hours = context_->grib_hourly_steps_with_units;
 
     eccodes::Step end_step{ end_step_value, end_step_unit };
 
     /*point in time */
-    if (self->year == NULL) {
+    if (year_ == NULL) {
         if ((err = grib_set_long_internal(h, "startStepUnit", end_step.unit().value<long>())) != GRIB_SUCCESS)
             return err;
-        err = grib_set_long_internal(h, self->start_step_value, end_step.value<long>());
+        err = grib_set_long_internal(h, start_step_value_, end_step.value<long>());
         return err;
     }
 
-    if ((err = grib_get_long_internal(h, self->time_range_unit, &time_range_unit)))
+    if ((err = grib_get_long_internal(h, time_range_unit_, &time_range_unit)))
         return err;
-    if ((err = grib_get_long_internal(h, self->year, &year)))
+    if ((err = grib_get_long_internal(h, year_, &year)))
         return err;
-    if ((err = grib_get_long_internal(h, self->month, &month)))
+    if ((err = grib_get_long_internal(h, month_, &month)))
         return err;
-    if ((err = grib_get_long_internal(h, self->day, &day)))
+    if ((err = grib_get_long_internal(h, day_, &day)))
         return err;
-    if ((err = grib_get_long_internal(h, self->hour, &hour)))
+    if ((err = grib_get_long_internal(h, hour_, &hour)))
         return err;
-    if ((err = grib_get_long_internal(h, self->minute, &minute)))
+    if ((err = grib_get_long_internal(h, minute_, &minute)))
         return err;
-    if ((err = grib_get_long_internal(h, self->second, &second)))
+    if ((err = grib_get_long_internal(h, second_, &second)))
         return err;
 
-    if ((err = grib_get_long_internal(h, self->start_step_value, &start_step_value)))
+    if ((err = grib_get_long_internal(h, start_step_value_, &start_step_value)))
         return err;
     if ((err = grib_get_long_internal(h, "startStepUnit", &start_step_unit)))
         return err;
@@ -477,7 +467,7 @@ static int pack_long_(grib_accessor* a, const long end_step_value, const long en
         return GRIB_WRONG_STEP_UNIT;
     }
 
-    if ((err = grib_get_long_internal(h, self->typeOfTimeIncrement, &typeOfTimeIncrement)))
+    if ((err = grib_get_long_internal(h, typeOfTimeIncrement_, &typeOfTimeIncrement)))
         return err;
 
     eccodes::Step start_step{ start_step_value, start_step_unit };
@@ -491,10 +481,11 @@ static int pack_long_(grib_accessor* a, const long end_step_value, const long en
         return GRIB_WRONG_STEP;
     }
 
-    if (!is_date_valid(year, month, day, hour, minute, second)) { // ECC-1866
-        grib_context_log(h->context, GRIB_LOG_ERROR, "%s:%s: Date/Time is not valid! "
-                        "year=%ld month=%ld day=%ld hour=%ld minute=%ld second=%ld",
-                        a->cclass->name, __func__, year, month, day, hour, minute, second);
+    if (!is_date_valid(year, month, day, hour, minute, second)) {  // ECC-1866
+        grib_context_log(h->context, GRIB_LOG_ERROR,
+                         "%s:%s: Date/Time is not valid! "
+                         "year=%ld month=%ld day=%ld hour=%ld minute=%ld second=%ld",
+                         class_name_, __func__, year, month, day, hour, minute, second);
         return GRIB_DECODING_ERROR;
     }
 
@@ -511,17 +502,17 @@ static int pack_long_(grib_accessor* a, const long end_step_value, const long en
     if (err != GRIB_SUCCESS)
         return err;
 
-    if ((err = grib_set_long_internal(h, self->year_of_end_of_interval, year_of_end_of_interval)))
+    if ((err = grib_set_long_internal(h, year_of_end_of_interval_, year_of_end_of_interval)))
         return err;
-    if ((err = grib_set_long_internal(h, self->month_of_end_of_interval, month_of_end_of_interval)))
+    if ((err = grib_set_long_internal(h, month_of_end_of_interval_, month_of_end_of_interval)))
         return err;
-    if ((err = grib_set_long_internal(h, self->day_of_end_of_interval, day_of_end_of_interval)))
+    if ((err = grib_set_long_internal(h, day_of_end_of_interval_, day_of_end_of_interval)))
         return err;
-    if ((err = grib_set_long_internal(h, self->hour_of_end_of_interval, hour_of_end_of_interval)))
+    if ((err = grib_set_long_internal(h, hour_of_end_of_interval_, hour_of_end_of_interval)))
         return err;
-    if ((err = grib_set_long_internal(h, self->minute_of_end_of_interval, minute_of_end_of_interval)))
+    if ((err = grib_set_long_internal(h, minute_of_end_of_interval_, minute_of_end_of_interval)))
         return err;
-    if ((err = grib_set_long_internal(h, self->second_of_end_of_interval, second_of_end_of_interval)))
+    if ((err = grib_set_long_internal(h, second_of_end_of_interval_, second_of_end_of_interval)))
         return err;
 
     const char* forecast_time_value_key = "forecastTime";
@@ -536,33 +527,32 @@ static int pack_long_(grib_accessor* a, const long end_step_value, const long en
         time_range_opt    = eccodes::Step{ time_range.value<long>(eccodes::Unit{ force_step_units }), eccodes::Unit{ force_step_units } };
     }
 
-    if ((err = grib_set_long_internal(grib_handle_of_accessor(a), self->time_range_value, time_range_opt.value<long>())) != GRIB_SUCCESS)
+    if ((err = grib_set_long_internal(h, time_range_value_, time_range_opt.value<long>())) != GRIB_SUCCESS)
         return err;
-    if ((err = grib_set_long_internal(grib_handle_of_accessor(a), self->time_range_unit, time_range_opt.unit().value<long>())) != GRIB_SUCCESS)
+    if ((err = grib_set_long_internal(h, time_range_unit_, time_range_opt.unit().value<long>())) != GRIB_SUCCESS)
         return err;
-    if ((err = grib_set_long_internal(grib_handle_of_accessor(a), forecast_time_value_key, forecast_time_opt.value<long>())) != GRIB_SUCCESS)
+    if ((err = grib_set_long_internal(h, forecast_time_value_key, forecast_time_opt.value<long>())) != GRIB_SUCCESS)
         return err;
-    if ((err = grib_set_long_internal(grib_handle_of_accessor(a), forecast_time_unit_key, forecast_time_opt.unit().value<long>())) != GRIB_SUCCESS)
+    if ((err = grib_set_long_internal(h, forecast_time_unit_key, forecast_time_opt.unit().value<long>())) != GRIB_SUCCESS)
         return err;
 
     return GRIB_SUCCESS;
 }
 
-int grib_accessor_class_g2end_step_t::unpack_string(grib_accessor* a, char* val, size_t* len)
+int grib_accessor_g2end_step_t::unpack_string(char* val, size_t* len)
 {
-    grib_accessor_g2end_step_t* self = (grib_accessor_g2end_step_t*)a;
-    grib_handle* h                   = grib_handle_of_accessor(a);
-    int ret                          = 0;
-    char fp_format[128]              = "%g";
-    size_t fp_format_len             = sizeof(fp_format);
-    size_t step_len                  = 0;
+    grib_handle* h       = grib_handle_of_accessor(this);
+    int ret              = 0;
+    char fp_format[128]  = "%g";
+    size_t fp_format_len = sizeof(fp_format);
+    size_t step_len      = 0;
     long step_value;
     long step_units;
-    const int show_units_for_hours = a->context->grib_hourly_steps_with_units;
+    const int show_units_for_hours = context_->grib_hourly_steps_with_units;
 
-    if ((ret = unpack_long(a, &step_value, &step_len)) != GRIB_SUCCESS)
+    if ((ret = unpack_long(&step_value, &step_len)) != GRIB_SUCCESS)
         return ret;
-    if ((ret = grib_get_long_internal(h, self->step_units, &step_units)) != GRIB_SUCCESS)
+    if ((ret = grib_get_long_internal(h, step_units_, &step_units)) != GRIB_SUCCESS)
         return ret;
     if ((ret = grib_get_string(h, "formatForDoubles", fp_format, &fp_format_len)) != GRIB_SUCCESS)
         return ret;
@@ -592,9 +582,9 @@ int grib_accessor_class_g2end_step_t::unpack_string(grib_accessor* a, char* val,
     return GRIB_SUCCESS;
 }
 
-int grib_accessor_class_g2end_step_t::pack_long(grib_accessor* a, const long* val, size_t* len)
+int grib_accessor_g2end_step_t::pack_long(const long* val, size_t* len)
 {
-    grib_handle* h = grib_handle_of_accessor(a);
+    grib_handle* h = grib_handle_of_accessor(this);
     int ret;
 
     long force_step_units;
@@ -613,7 +603,7 @@ int grib_accessor_class_g2end_step_t::pack_long(grib_accessor* a, const long* va
         else {
             end_step_unit = force_step_units;
         }
-        ret = pack_long_(a, *val, end_step_unit);
+        ret = pack_long_(*val, end_step_unit);
     }
     catch (std::exception& e) {
         grib_context_log(h->context, GRIB_LOG_ERROR, "grib_accessor_g2end_step_t::pack_long: %s", e.what());
@@ -622,9 +612,9 @@ int grib_accessor_class_g2end_step_t::pack_long(grib_accessor* a, const long* va
     return ret;
 }
 
-int grib_accessor_class_g2end_step_t::pack_string(grib_accessor* a, const char* val, size_t* len)
+int grib_accessor_g2end_step_t::pack_string(const char* val, size_t* len)
 {
-    grib_handle* h = grib_handle_of_accessor(a);
+    grib_handle* h = grib_handle_of_accessor(this);
     int ret        = 0;
     long force_step_units;
     if ((ret = grib_get_long_internal(h, "forceStepUnits", &force_step_units)) != GRIB_SUCCESS)
@@ -637,7 +627,7 @@ int grib_accessor_class_g2end_step_t::pack_string(grib_accessor* a, const char*
         if ((ret = grib_set_long_internal(h, "endStepUnit", end_step.unit().value<long>())) != GRIB_SUCCESS)
             return ret;
 
-        if ((ret = pack_long_(a, end_step.value<long>(), end_step.unit().value<long>())) != GRIB_SUCCESS)
+        if ((ret = pack_long_(end_step.value<long>(), end_step.unit().value<long>())) != GRIB_SUCCESS)
             return ret;
     }
     catch (std::exception& e) {
@@ -647,10 +637,10 @@ int grib_accessor_class_g2end_step_t::pack_string(grib_accessor* a, const char*
     return GRIB_SUCCESS;
 }
 
-int grib_accessor_class_g2end_step_t::get_native_type(grib_accessor* a)
+long grib_accessor_g2end_step_t::get_native_type()
 {
-    grib_handle* h                 = grib_handle_of_accessor(a);
-    const int show_units_for_hours = a->context->grib_hourly_steps_with_units;
+    grib_handle* h = grib_handle_of_accessor(this);
+    const int show_units_for_hours = context_->grib_hourly_steps_with_units;
 
     if (!show_units_for_hours) {
         long step_units = 0;
