@@ -1,4 +1,3 @@
-
 /*
  * (C) Copyright 2005- ECMWF.
  *
@@ -16,16 +15,11 @@
 class grib_accessor_sexagesimal2decimal_t : public grib_accessor_to_double_t
 {
 public:
-    /* Members defined in sexagesimal2decimal */
-};
-
-class grib_accessor_class_sexagesimal2decimal_t : public grib_accessor_class_to_double_t
-{
-public:
-    grib_accessor_class_sexagesimal2decimal_t(const char* name) : grib_accessor_class_to_double_t(name) {}
+    grib_accessor_sexagesimal2decimal_t() :
+        grib_accessor_to_double_t() { class_name_ = "sexagesimal2decimal"; }
     grib_accessor* create_empty_accessor() override { return new grib_accessor_sexagesimal2decimal_t{}; }
-    int get_native_type(grib_accessor*) override;
-    int unpack_string(grib_accessor*, char*, size_t* len) override;
-    void dump(grib_accessor*, grib_dumper*) override;
-    void init(grib_accessor*, const long, grib_arguments*) override;
+    long get_native_type() override;
+    int unpack_string(char*, size_t* len) override;
+    void dump(grib_dumper*) override;
+    void init(const long, grib_arguments*) override;
 };
