@@ -1,4 +1,3 @@
-
 /*
  * (C) Copyright 2005- ECMWF.
  *
@@ -16,20 +15,18 @@
 class grib_accessor_smart_table_column_t : public grib_accessor_gen_t
 {
 public:
-    const char* smartTable;
-    int index;
-};
-
-class grib_accessor_class_smart_table_column_t : public grib_accessor_class_gen_t
-{
-public:
-    grib_accessor_class_smart_table_column_t(const char* name) : grib_accessor_class_gen_t(name) {}
+    grib_accessor_smart_table_column_t() :
+        grib_accessor_gen_t() { class_name_ = "smart_table_column"; }
     grib_accessor* create_empty_accessor() override { return new grib_accessor_smart_table_column_t{}; }
-    int get_native_type(grib_accessor*) override;
-    int unpack_long(grib_accessor*, long* val, size_t* len) override;
-    int unpack_string_array(grib_accessor*, char**, size_t* len) override;
-    int value_count(grib_accessor*, long*) override;
-    void destroy(grib_context*, grib_accessor*) override;
-    void dump(grib_accessor*, grib_dumper*) override;
-    void init(grib_accessor*, const long, grib_arguments*) override;
+    long get_native_type() override;
+    int unpack_long(long* val, size_t* len) override;
+    int unpack_string_array(char**, size_t* len) override;
+    int value_count(long*) override;
+    void destroy(grib_context*) override;
+    void dump(grib_dumper*) override;
+    void init(const long, grib_arguments*) override;
+
+private:
+    const char* smartTable_ = nullptr;
+    int index_ = 0;
 };
