@@ -9,7 +9,7 @@
  */
 
 #include "grib_api_internal.h"
-#include <ctype.h>
+#include <cctype>
 /*
    This is used by make_class.pl
 
@@ -102,13 +102,14 @@ static void init_class(grib_dumper_class* c) {}
 static int init(grib_dumper* d)
 {
     grib_dumper_bufr_encode_C* self = (grib_dumper_bufr_encode_C*)d;
-    grib_context* c                 = d->context;
-    self->section_offset            = 0;
-    self->empty                     = 1;
-    d->count                        = 1;
-    self->isLeaf                    = 0;
-    self->isAttribute               = 0;
-    self->keys                      = (grib_string_list*)grib_context_malloc_clear(c, sizeof(grib_string_list));
+
+    grib_context* c      = d->context;
+    self->section_offset = 0;
+    self->empty          = 1;
+    d->count             = 1;
+    self->isLeaf         = 0;
+    self->isAttribute    = 0;
+    self->keys           = (grib_string_list*)grib_context_malloc_clear(c, sizeof(grib_string_list));
 
     return GRIB_SUCCESS;
 }
@@ -116,9 +117,9 @@ static int init(grib_dumper* d)
 static int destroy(grib_dumper* d)
 {
     grib_dumper_bufr_encode_C* self = (grib_dumper_bufr_encode_C*)d;
-    grib_string_list* next          = self->keys;
-    grib_string_list* cur           = NULL;
-    grib_context* c                 = d->context;
+    grib_string_list* next = self->keys;
+    grib_string_list* cur = NULL;
+    grib_context* c = d->context;
     while (next) {
         cur  = next;
         next = next->next;
@@ -152,29 +153,30 @@ static char* dval_to_string(grib_context* c, double v)
 static void dump_values(grib_dumper* d, grib_accessor* a)
 {
     grib_dumper_bufr_encode_C* self = (grib_dumper_bufr_encode_C*)d;
-    double value                    = 0;
+
+    double value = 0;
     size_t size = 0, size2 = 0;
-    double* values                  = NULL;
-    int err                         = 0;
+    double* values = NULL;
+    int err = 0;
     int i, r, icount;
     int cols   = 2;
     long count = 0;
     char* sval;
-    grib_context* c = a->context;
+    grib_context* c = a->context_;
     grib_handle* h  = grib_handle_of_accessor(a);
 
-    if ((a->flags & GRIB_ACCESSOR_FLAG_DUMP) == 0 || (a->flags & GRIB_ACCESSOR_FLAG_READ_ONLY) != 0)
+    if ((a->flags_ & GRIB_ACCESSOR_FLAG_DUMP) == 0 || (a->flags_ & GRIB_ACCESSOR_FLAG_READ_ONLY) != 0)
         return;
 
-    grib_value_count(a, &count);
+    a->value_count(&count);
     size = size2 = count;
 
     if (size > 1) {
         values = (double*)grib_context_malloc_clear(c, sizeof(double) * size);
-        err    = grib_unpack_double(a, values, &size2);
+        err    = a->unpack_double(values, &size2);
     }
     else {
-        err = grib_unpack_double(a, &value, &size2);
+        err = a->unpack_double(&value, &size2);
     }
     Assert(size2 == size);
 
@@ -184,7 +186,7 @@ static void dump_values(grib_dumper* d, grib_accessor* a)
         fprintf(self->dumper.out, "  free(rvalues); rvalues = NULL;\n\n");
         fprintf(self->dumper.out, "  size = %lu;\n", (unsigned long)size);
         fprintf(self->dumper.out, "  rvalues = (double*)malloc(size * sizeof(double));\n");
-        fprintf(self->dumper.out, "  if (!rvalues) { fprintf(stderr, \"Failed to allocate memory (%s).\\n\"); return 1; }", a->name);
+        fprintf(self->dumper.out, "  if (!rvalues) { fprintf(stderr, \"Failed to allocate memory (%s).\\n\"); return 1; }", a->name_);
 
         icount = 0;
         for (i = 0; i < size - 1; ++i) {
@@ -208,18 +210,18 @@ static void dump_values(grib_dumper* d, grib_accessor* a)
         fprintf(self->dumper.out, "\n");
         grib_context_free(c, values);
 
-        if ((r = compute_bufr_key_rank(h, self->keys, a->name)) != 0)
-            fprintf(self->dumper.out, "  CODES_CHECK(codes_set_double_array(h, \"#%d#%s\",rvalues, size), 0);\n", r, a->name);
+        if ((r = compute_bufr_key_rank(h, self->keys, a->name_)) != 0)
+            fprintf(self->dumper.out, "  CODES_CHECK(codes_set_double_array(h, \"#%d#%s\",rvalues, size), 0);\n", r, a->name_);
         else
-            fprintf(self->dumper.out, "  CODES_CHECK(codes_set_double_array(h, \"%s\", rvalues, size), 0);\n", a->name);
+            fprintf(self->dumper.out, "  CODES_CHECK(codes_set_double_array(h, \"%s\", rvalues, size), 0);\n", a->name_);
     }
     else {
-        r    = compute_bufr_key_rank(h, self->keys, a->name);
+        r    = compute_bufr_key_rank(h, self->keys, a->name_);
         sval = dval_to_string(c, value);
         if (r != 0)
-            fprintf(self->dumper.out, "  CODES_CHECK(codes_set_double(h, \"#%d#%s\", %s), 0);\n", r, a->name, sval);
+            fprintf(self->dumper.out, "  CODES_CHECK(codes_set_double(h, \"#%d#%s\", %s), 0);\n", r, a->name_, sval);
         else
-            fprintf(self->dumper.out, "  CODES_CHECK(codes_set_double(h, \"%s\", %s), 0);\n", a->name, sval);
+            fprintf(self->dumper.out, "  CODES_CHECK(codes_set_double(h, \"%s\", %s), 0);\n", a->name_, sval);
         grib_context_free(c, sval);
     }
 
@@ -228,13 +230,13 @@ static void dump_values(grib_dumper* d, grib_accessor* a)
         int dofree = 0;
 
         if (r != 0) {
-            const size_t prefixMaxLen = strlen(a->name) + 10;
+            const size_t prefixMaxLen = strlen(a->name_) + 10;
             prefix = (char*)grib_context_malloc_clear(c, sizeof(char) * prefixMaxLen);
             dofree = 1;
-            snprintf(prefix, prefixMaxLen, "#%d#%s", r, a->name);
+            snprintf(prefix, prefixMaxLen, "#%d#%s", r, a->name_);
         }
         else
-            prefix = (char*)a->name;
+            prefix = (char*)a->name_;
 
         dump_attributes(d, a, prefix);
         if (dofree)
@@ -248,28 +250,29 @@ static void dump_values(grib_dumper* d, grib_accessor* a)
 static void dump_values_attribute(grib_dumper* d, grib_accessor* a, const char* prefix)
 {
     grib_dumper_bufr_encode_C* self = (grib_dumper_bufr_encode_C*)d;
-    double value                    = 0;
+
+    double value = 0;
     size_t size = 0, size2 = 0;
-    double* values                  = NULL;
-    int err                         = 0;
+    double* values = NULL;
+    int err        = 0;
     int i, icount;
     int cols   = 2;
     long count = 0;
     char* sval;
-    grib_context* c = a->context;
+    grib_context* c = a->context_;
 
-    if ((a->flags & GRIB_ACCESSOR_FLAG_DUMP) == 0 || (a->flags & GRIB_ACCESSOR_FLAG_READ_ONLY) != 0)
+    if ((a->flags_ & GRIB_ACCESSOR_FLAG_DUMP) == 0 || (a->flags_ & GRIB_ACCESSOR_FLAG_READ_ONLY) != 0)
         return;
 
-    grib_value_count(a, &count);
+    a->value_count(&count);
     size = size2 = count;
 
     if (size > 1) {
         values = (double*)grib_context_malloc_clear(c, sizeof(double) * size);
-        err    = grib_unpack_double(a, values, &size2);
+        err    = a->unpack_double(values, &size2);
     }
     else {
-        err = grib_unpack_double(a, &value, &size2);
+        err = a->unpack_double(&value, &size2);
     }
     Assert(size2 == size);
 
@@ -279,7 +282,7 @@ static void dump_values_attribute(grib_dumper* d, grib_accessor* a, const char*
         fprintf(self->dumper.out, "  free(rvalues); rvalues = NULL;\n");
         fprintf(self->dumper.out, "  size = %lu;\n", (unsigned long)size);
         fprintf(self->dumper.out, "  rvalues = (double*)malloc(size * sizeof(double));\n");
-        fprintf(self->dumper.out, "  if (!rvalues) { fprintf(stderr, \"Failed to allocate memory (%s).\\n\"); return 1; }", a->name);
+        fprintf(self->dumper.out, "  if (!rvalues) { fprintf(stderr, \"Failed to allocate memory (%s).\\n\"); return 1; }", a->name_);
 
         icount = 0;
         for (i = 0; i < size - 1; ++i) {
@@ -303,18 +306,18 @@ static void dump_values_attribute(grib_dumper* d, grib_accessor* a, const char*
         fprintf(self->dumper.out, "\n");
         grib_context_free(c, values);
 
-        fprintf(self->dumper.out, "  CODES_CHECK(codes_set_double_array(h, \"%s->%s\", rvalues, size), 0);\n", prefix, a->name);
+        fprintf(self->dumper.out, "  CODES_CHECK(codes_set_double_array(h, \"%s->%s\", rvalues, size), 0);\n", prefix, a->name_);
     }
     else {
         sval = dval_to_string(c, value);
-        fprintf(self->dumper.out, "  CODES_CHECK(codes_set_double(h, \"%s->%s\", %s), 0);\n", prefix, a->name, sval);
+        fprintf(self->dumper.out, "  CODES_CHECK(codes_set_double(h, \"%s->%s\", %s), 0);\n", prefix, a->name_, sval);
         grib_context_free(c, sval);
     }
 
     if (self->isLeaf == 0) {
-        const size_t prefix1MaxLen =  strlen(a->name) + strlen(prefix) + 5;
+        const size_t prefix1MaxLen =  strlen(a->name_) + strlen(prefix) + 5;
         char* prefix1 = (char*)grib_context_malloc_clear(c, sizeof(char) * prefix1MaxLen);
-        snprintf(prefix1, prefix1MaxLen, "%s->%s", prefix, a->name);
+        snprintf(prefix1, prefix1MaxLen, "%s->%s", prefix, a->name_);
 
         dump_attributes(d, a, prefix1);
 
@@ -327,49 +330,50 @@ static void dump_values_attribute(grib_dumper* d, grib_accessor* a, const char*
 
 static int is_hidden(grib_accessor* a)
 {
-    return ( (a->flags & GRIB_ACCESSOR_FLAG_HIDDEN) != 0 );
+    return ( (a->flags_ & GRIB_ACCESSOR_FLAG_HIDDEN) != 0 );
 }
 
 static void dump_long(grib_dumper* d, grib_accessor* a, const char* comment)
 {
     grib_dumper_bufr_encode_C* self = (grib_dumper_bufr_encode_C*)d;
-    long value                      = 0;
+
+    long value  = 0;
     size_t size = 0, size2 = 0;
-    long* values                    = NULL;
-    int err                         = 0;
+    long* values = NULL;
+    int err      = 0;
     int i, r, icount;
-    int cols                        = 4;
-    long count                      = 0;
-    char* sval                      = NULL;
-    grib_context* c                 = a->context;
-    grib_handle* h                  = grib_handle_of_accessor(a);
+    int cols = 4;
+    long count = 0;
+    char* sval = NULL;
+    grib_context* c = a->context_;
+    grib_handle* h = grib_handle_of_accessor(a);
     int doing_unexpandedDescriptors = 0;
 
-    if ((a->flags & GRIB_ACCESSOR_FLAG_DUMP) == 0) { /* key does not have the dump attribute */
+    if ((a->flags_ & GRIB_ACCESSOR_FLAG_DUMP) == 0) { /* key does not have the dump attribute */
         int skip = 1;
         /* See ECC-1107 */
-        if (!is_hidden(a) && strcmp(a->name, "messageLength") == 0) skip = 0;
+        if (!is_hidden(a) && strcmp(a->name_, "messageLength") == 0) skip = 0;
         if (skip) return;
     }
 
-    doing_unexpandedDescriptors = (strcmp(a->name, "unexpandedDescriptors") == 0);
-    grib_value_count(a, &count);
+    doing_unexpandedDescriptors = (strcmp(a->name_, "unexpandedDescriptors") == 0);
+    a->value_count(&count);
     size = size2 = count;
 
-    if ((a->flags & GRIB_ACCESSOR_FLAG_READ_ONLY) != 0) {
+    if ((a->flags_ & GRIB_ACCESSOR_FLAG_READ_ONLY) != 0) {
         if (self->isLeaf == 0) {
             char* prefix;
             int dofree = 0;
 
-            r = compute_bufr_key_rank(h, self->keys, a->name);
+            r = compute_bufr_key_rank(h, self->keys, a->name_);
             if (r != 0) {
-                const size_t prefixMaxLen = strlen(a->name) + 10;
+                const size_t prefixMaxLen = strlen(a->name_) + 10;
                 prefix = (char*)grib_context_malloc_clear(c, sizeof(char) * prefixMaxLen);
                 dofree = 1;
-                snprintf(prefix, prefixMaxLen, "#%d#%s", r, a->name);
+                snprintf(prefix, prefixMaxLen, "#%d#%s", r, a->name_);
             }
             else
-                prefix = (char*)a->name;
+                prefix = (char*)a->name_;
 
             dump_attributes(d, a, prefix);
             if (dofree)
@@ -380,11 +384,11 @@ static void dump_long(grib_dumper* d, grib_accessor* a, const char* comment)
     }
 
     if (size > 1) {
-        values = (long*)grib_context_malloc_clear(a->context, sizeof(long) * size);
-        err    = grib_unpack_long(a, values, &size2);
+        values = (long*)grib_context_malloc_clear(a->context_, sizeof(long) * size);
+        err    = a->unpack_long(values, &size2);
     }
     else {
-        err = grib_unpack_long(a, &value, &size2);
+        err = a->unpack_long(&value, &size2);
     }
     Assert(size2 == size);
 
@@ -394,7 +398,7 @@ static void dump_long(grib_dumper* d, grib_accessor* a, const char* comment)
         fprintf(self->dumper.out, "  free(ivalues); ivalues = NULL;\n\n");
         fprintf(self->dumper.out, "  size = %lu;\n", (unsigned long)size);
         fprintf(self->dumper.out, "  ivalues = (long*)malloc(size * sizeof(long));\n");
-        fprintf(self->dumper.out, "  if (!ivalues) { fprintf(stderr, \"Failed to allocate memory (%s).\\n\"); return 1; }", a->name);
+        fprintf(self->dumper.out, "  if (!ivalues) { fprintf(stderr, \"Failed to allocate memory (%s).\\n\"); return 1; }", a->name_);
 
         icount = 0;
         for (i = 0; i < size - 1; i++) {
@@ -412,33 +416,33 @@ static void dump_long(grib_dumper* d, grib_accessor* a, const char* comment)
 
         depth -= 2;
         fprintf(self->dumper.out, "\n");
-        grib_context_free(a->context, values);
+        grib_context_free(a->context_, values);
 
-        if ((r = compute_bufr_key_rank(h, self->keys, a->name)) != 0) {
-            fprintf(self->dumper.out, "  CODES_CHECK(codes_set_long_array(h, \"#%d#%s\", ivalues, size), 0);\n", r, a->name);
+        if ((r = compute_bufr_key_rank(h, self->keys, a->name_)) != 0) {
+            fprintf(self->dumper.out, "  CODES_CHECK(codes_set_long_array(h, \"#%d#%s\", ivalues, size), 0);\n", r, a->name_);
         }
         else {
             if (doing_unexpandedDescriptors) {
                 fprintf(self->dumper.out, "\n  /* Create the structure of the data section */\n");
                 /* fprintf(self->dumper.out,"  CODES_CHECK(codes_set_long(h, \"skipExtraKeyAttributes\", 1), 0);\n"); */
             }
-            fprintf(self->dumper.out, "  CODES_CHECK(codes_set_long_array(h, \"%s\", ivalues, size), 0);\n", a->name);
+            fprintf(self->dumper.out, "  CODES_CHECK(codes_set_long_array(h, \"%s\", ivalues, size), 0);\n", a->name_);
             if (doing_unexpandedDescriptors)
                 fprintf(self->dumper.out, "\n");
         }
     }
     else {
-        r    = compute_bufr_key_rank(h, self->keys, a->name);
+        r    = compute_bufr_key_rank(h, self->keys, a->name_);
         sval = lval_to_string(c, value);
         if (r != 0) {
-            fprintf(self->dumper.out, "  CODES_CHECK(codes_set_long(h, \"#%d#%s\", ", r, a->name);
+            fprintf(self->dumper.out, "  CODES_CHECK(codes_set_long(h, \"#%d#%s\", ", r, a->name_);
         }
         else {
             if (doing_unexpandedDescriptors) {
                 fprintf(self->dumper.out, "\n  /* Create the structure of the data section */\n");
                 /* fprintf(self->dumper.out,"  CODES_CHECK(codes_set_long(h, \"skipExtraKeyAttributes\", 1), 0);\n"); */
             }
-            fprintf(self->dumper.out, "  CODES_CHECK(codes_set_long(h, \"%s\", ", a->name);
+            fprintf(self->dumper.out, "  CODES_CHECK(codes_set_long(h, \"%s\", ", a->name_);
         }
 
         fprintf(self->dumper.out, "%s), 0);\n", sval);
@@ -452,13 +456,13 @@ static void dump_long(grib_dumper* d, grib_accessor* a, const char* comment)
         int dofree = 0;
 
         if (r != 0) {
-            const size_t prefixMaxLen = strlen(a->name) + 10;
+            const size_t prefixMaxLen = strlen(a->name_) + 10;
             prefix = (char*)grib_context_malloc_clear(c, sizeof(char) * prefixMaxLen);
             dofree = 1;
-            snprintf(prefix, prefixMaxLen, "#%d#%s", r, a->name);
+            snprintf(prefix, prefixMaxLen, "#%d#%s", r, a->name_);
         }
         else
-            prefix = (char*)a->name;
+            prefix = (char*)a->name_;
 
         dump_attributes(d, a, prefix);
         if (dofree)
@@ -471,27 +475,28 @@ static void dump_long(grib_dumper* d, grib_accessor* a, const char* comment)
 static void dump_long_attribute(grib_dumper* d, grib_accessor* a, const char* prefix)
 {
     grib_dumper_bufr_encode_C* self = (grib_dumper_bufr_encode_C*)d;
-    long value                      = 0;
+
+    long value  = 0;
     size_t size = 0, size2 = 0;
-    long* values                    = NULL;
-    int err                         = 0;
+    long* values = NULL;
+    int err      = 0;
     int i, icount;
     int cols        = 4;
     long count      = 0;
-    grib_context* c = a->context;
+    grib_context* c = a->context_;
 
-    if ((a->flags & GRIB_ACCESSOR_FLAG_DUMP) == 0 || (a->flags & GRIB_ACCESSOR_FLAG_READ_ONLY) != 0)
+    if ((a->flags_ & GRIB_ACCESSOR_FLAG_DUMP) == 0 || (a->flags_ & GRIB_ACCESSOR_FLAG_READ_ONLY) != 0)
         return;
 
-    grib_value_count(a, &count);
+    a->value_count(&count);
     size = size2 = count;
 
     if (size > 1) {
-        values = (long*)grib_context_malloc_clear(a->context, sizeof(long) * size);
-        err    = grib_unpack_long(a, values, &size2);
+        values = (long*)grib_context_malloc_clear(a->context_, sizeof(long) * size);
+        err    = a->unpack_long(values, &size2);
     }
     else {
-        err = grib_unpack_long(a, &value, &size2);
+        err = a->unpack_long(&value, &size2);
     }
     Assert(size2 == size);
 
@@ -501,7 +506,7 @@ static void dump_long_attribute(grib_dumper* d, grib_accessor* a, const char* pr
         fprintf(self->dumper.out, "  free(ivalues); ivalues = NULL;\n");
         fprintf(self->dumper.out, "  size = %lu;\n", (unsigned long)size);
         fprintf(self->dumper.out, "  ivalues = (long*)malloc(size * sizeof(long));\n");
-        fprintf(self->dumper.out, "  if (!ivalues) { fprintf(stderr, \"Failed to allocate memory (%s).\\n\"); return 1; }", a->name);
+        fprintf(self->dumper.out, "  if (!ivalues) { fprintf(stderr, \"Failed to allocate memory (%s).\\n\"); return 1; }", a->name_);
 
         icount = 0;
         for (i = 0; i < size - 1; i++) {
@@ -519,21 +524,23 @@ static void dump_long_attribute(grib_dumper* d, grib_accessor* a, const char* pr
 
         depth -= 2;
         fprintf(self->dumper.out, "\n");
-        grib_context_free(a->context, values);
+        grib_context_free(a->context_, values);
 
-        fprintf(self->dumper.out, "  CODES_CHECK(codes_set_long_array(h, \"%s->%s\", ivalues, size), 0);\n", prefix, a->name);
+        fprintf(self->dumper.out, "  CODES_CHECK(codes_set_long_array(h, \"%s->%s\", ivalues, size), 0);\n", prefix, a->name_);
     }
     else {
-        char* sval = lval_to_string(c, value);
-        fprintf(self->dumper.out, "  CODES_CHECK(codes_set_long(h, \"%s->%s\", ", prefix, a->name);
-        fprintf(self->dumper.out, "%s), 0);\n", sval);
-        grib_context_free(c, sval);
+        if (!codes_bufr_key_exclude_from_dump(prefix)) {
+            char* sval = lval_to_string(c, value);
+            fprintf(self->dumper.out, "  CODES_CHECK(codes_set_long(h, \"%s->%s\", ", prefix, a->name_);
+            fprintf(self->dumper.out, "%s), 0);\n", sval);
+            grib_context_free(c, sval);
+        }
     }
 
     if (self->isLeaf == 0) {
-        const size_t prefix1MaxLen = strlen(a->name) + strlen(prefix) + 5;
+        const size_t prefix1MaxLen = strlen(a->name_) + strlen(prefix) + 5;
         char* prefix1 = (char*)grib_context_malloc_clear(c, sizeof(char) * prefix1MaxLen);
-        snprintf(prefix1, prefix1MaxLen, "%s->%s", prefix, a->name);
+        snprintf(prefix1, prefix1MaxLen, "%s->%s", prefix, a->name_);
 
         dump_attributes(d, a, prefix1);
 
@@ -550,26 +557,27 @@ static void dump_bits(grib_dumper* d, grib_accessor* a, const char* comment)
 static void dump_double(grib_dumper* d, grib_accessor* a, const char* comment)
 {
     grib_dumper_bufr_encode_C* self = (grib_dumper_bufr_encode_C*)d;
-    double value                    = 0;
-    size_t size                     = 1;
+
+    double value = 0;
+    size_t size  = 1;
     int r;
     char* sval;
     grib_handle* h  = grib_handle_of_accessor(a);
     grib_context* c = h->context;
 
-    if ((a->flags & GRIB_ACCESSOR_FLAG_DUMP) == 0 || (a->flags & GRIB_ACCESSOR_FLAG_READ_ONLY) != 0)
+    if ((a->flags_ & GRIB_ACCESSOR_FLAG_DUMP) == 0 || (a->flags_ & GRIB_ACCESSOR_FLAG_READ_ONLY) != 0)
         return;
 
-    grib_unpack_double(a, &value, &size);
+    a->unpack_double(&value, &size);
     self->empty = 0;
 
-    r = compute_bufr_key_rank(h, self->keys, a->name);
+    r = compute_bufr_key_rank(h, self->keys, a->name_);
 
     sval = dval_to_string(c, value);
     if (r != 0)
-        fprintf(self->dumper.out, "  CODES_CHECK(codes_set_double(h, \"#%d#%s\", %s), 0);\n", r, a->name, sval);
+        fprintf(self->dumper.out, "  CODES_CHECK(codes_set_double(h, \"#%d#%s\", %s), 0);\n", r, a->name_, sval);
     else
-        fprintf(self->dumper.out, "  CODES_CHECK(codes_set_double(h, \"%s\", %s), 0);\n", a->name, sval);
+        fprintf(self->dumper.out, "  CODES_CHECK(codes_set_double(h, \"%s\", %s), 0);\n", a->name_, sval);
     grib_context_free(c, sval);
 
     if (self->isLeaf == 0) {
@@ -577,13 +585,13 @@ static void dump_double(grib_dumper* d, grib_accessor* a, const char* comment)
         int dofree = 0;
 
         if (r != 0) {
-            const size_t prefixMaxLen = strlen(a->name) + 10;
+            const size_t prefixMaxLen = strlen(a->name_) + 10;
             prefix = (char*)grib_context_malloc_clear(c, sizeof(char) * prefixMaxLen);
             dofree = 1;
-            snprintf(prefix, prefixMaxLen, "#%d#%s", r, a->name);
+            snprintf(prefix, prefixMaxLen, "#%d#%s", r, a->name_);
         }
         else
-            prefix = (char*)a->name;
+            prefix = (char*)a->name_;
 
         dump_attributes(d, a, prefix);
         if (dofree)
@@ -597,16 +605,16 @@ static void dump_string_array(grib_dumper* d, grib_accessor* a, const char* comm
     grib_dumper_bufr_encode_C* self = (grib_dumper_bufr_encode_C*)d;
     char** values;
     size_t size = 0, i = 0;
-    grib_context* c = a->context;
+    grib_context* c = a->context_;
     int err         = 0;
     long count      = 0;
     int r           = 0;
     grib_handle* h  = grib_handle_of_accessor(a);
 
-    if ((a->flags & GRIB_ACCESSOR_FLAG_DUMP) == 0 || (a->flags & GRIB_ACCESSOR_FLAG_READ_ONLY) != 0)
+    if ((a->flags_ & GRIB_ACCESSOR_FLAG_DUMP) == 0 || (a->flags_ & GRIB_ACCESSOR_FLAG_READ_ONLY) != 0)
         return;
 
-    grib_value_count(a, &count);
+    a->value_count(&count);
     size = count;
     if (size == 1) {
         dump_string(d, a, comment);
@@ -616,7 +624,7 @@ static void dump_string_array(grib_dumper* d, grib_accessor* a, const char* comm
     fprintf(self->dumper.out, "  free(svalues);\n");
     fprintf(self->dumper.out, "  size = %lu;\n", (unsigned long)size);
     fprintf(self->dumper.out, "  svalues = (char**)malloc(size * sizeof(char*));\n");
-    fprintf(self->dumper.out, "  if (!svalues) { fprintf(stderr, \"Failed to allocate memory (%s).\\n\"); return 1; }\n", a->name);
+    fprintf(self->dumper.out, "  if (!svalues) { fprintf(stderr, \"Failed to allocate memory (%s).\\n\"); return 1; }\n", a->name_);
 
     self->empty = 0;
     values      = (char**)grib_context_malloc_clear(c, size * sizeof(char*));
@@ -625,17 +633,17 @@ static void dump_string_array(grib_dumper* d, grib_accessor* a, const char* comm
         return;
     }
 
-    err = grib_unpack_string_array(a, values, &size);
+    err = a->unpack_string_array(values, &size);
     for (i = 0; i < size - 1; i++) {
         fprintf(self->dumper.out, "  svalues[%lu]=\"%s\"; \n", (unsigned long)i, values[i]);
     }
     fprintf(self->dumper.out, "  svalues[%lu]=\"%s\";\n", (unsigned long)i, values[i]);
 
     if (self->isLeaf == 0) {
-        if ((r = compute_bufr_key_rank(h, self->keys, a->name)) != 0)
-            fprintf(self->dumper.out, "  codes_set_string_array(h, \"#%d#%s\", (const char **)svalues, size);\n", r, a->name);
+        if ((r = compute_bufr_key_rank(h, self->keys, a->name_)) != 0)
+            fprintf(self->dumper.out, "  codes_set_string_array(h, \"#%d#%s\", (const char **)svalues, size);\n", r, a->name_);
         else
-            fprintf(self->dumper.out, "  codes_set_string_array(h, \"%s\", (const char **)svalues, size);\n", a->name);
+            fprintf(self->dumper.out, "  codes_set_string_array(h, \"%s\", (const char **)svalues, size);\n", a->name_);
     }
 
     if (self->isLeaf == 0) {
@@ -643,13 +651,13 @@ static void dump_string_array(grib_dumper* d, grib_accessor* a, const char* comm
         int dofree = 0;
 
         if (r != 0) {
-            const size_t prefixMaxLen = strlen(a->name) + 10;
+            const size_t prefixMaxLen = strlen(a->name_) + 10;
             prefix = (char*)grib_context_malloc_clear(c, sizeof(char) * prefixMaxLen);
             dofree = 1;
-            snprintf(prefix, prefixMaxLen, "#%d#%s", r, a->name);
+            snprintf(prefix, prefixMaxLen, "#%d#%s", r, a->name_);
         }
         else
-            prefix = (char*)a->name;
+            prefix = (char*)a->name_;
 
         dump_attributes(d, a, prefix);
         if (dofree)
@@ -665,19 +673,20 @@ static void dump_string_array(grib_dumper* d, grib_accessor* a, const char* comm
 static void dump_string(grib_dumper* d, grib_accessor* a, const char* comment)
 {
     grib_dumper_bufr_encode_C* self = (grib_dumper_bufr_encode_C*)d;
-    char* value                     = NULL;
-    char* p                         = NULL;
-    size_t size                     = 0;
-    grib_context* c                 = a->context;
-    int r = 0, err = 0;
-    grib_handle* h = grib_handle_of_accessor(a);
-    const char* acc_name = a->name;
 
-    ecc__grib_get_string_length(a, &size);
+    char* value     = NULL;
+    char* p         = NULL;
+    size_t size     = 0;
+    grib_context* c = a->context_;
+    int r = 0, err = 0;
+    grib_handle* h       = grib_handle_of_accessor(a);
+    const char* acc_name = a->name_;
+
+    grib_get_string_length_acc(a, &size);
     if (size == 0)
         return;
 
-    if ((a->flags & GRIB_ACCESSOR_FLAG_DUMP) == 0 || (a->flags & GRIB_ACCESSOR_FLAG_READ_ONLY) != 0)
+    if ((a->flags_ & GRIB_ACCESSOR_FLAG_DUMP) == 0 || (a->flags_ & GRIB_ACCESSOR_FLAG_READ_ONLY) != 0)
         return;
 
     value = (char*)grib_context_malloc_clear(c, size);
@@ -688,7 +697,7 @@ static void dump_string(grib_dumper* d, grib_accessor* a, const char* comment)
 
     self->empty = 0;
 
-    err = grib_unpack_string(a, value, &size);
+    err = a->unpack_string(value, &size);
     p   = value;
     r   = compute_bufr_key_rank(h, self->keys, acc_name);
     if (grib_is_missing_string(a, (unsigned char*)value, size)) {
@@ -782,9 +791,9 @@ static void _dump_long_array(grib_handle* h, FILE* f, const char* key, const cha
 static void dump_section(grib_dumper* d, grib_accessor* a, grib_block_of_accessors* block)
 {
     grib_dumper_bufr_encode_C* self = (grib_dumper_bufr_encode_C*)d;
-    if (strcmp(a->name, "BUFR")==0 ||
-        strcmp(a->name, "GRIB")==0 ||
-        strcmp(a->name, "META")==0) {
+    if (strcmp(a->name_, "BUFR")==0 ||
+        strcmp(a->name_, "GRIB")==0 ||
+        strcmp(a->name_, "META")==0) {
         grib_handle* h = grib_handle_of_accessor(a);
         depth          = 2;
         self->empty    = 1;
@@ -797,8 +806,8 @@ static void dump_section(grib_dumper* d, grib_accessor* a, grib_block_of_accesso
         grib_dump_accessors_block(d, block);
         depth -= 2;
     }
-    else if (strcmp(a->name, "groupNumber")==0) {
-        if ((a->flags & GRIB_ACCESSOR_FLAG_DUMP) == 0)
+    else if (strcmp(a->name_, "groupNumber")==0) {
+        if ((a->flags_ & GRIB_ACCESSOR_FLAG_DUMP) == 0)
             return;
         self->empty = 1;
         depth += 2;
@@ -812,29 +821,29 @@ static void dump_section(grib_dumper* d, grib_accessor* a, grib_block_of_accesso
 
 static void dump_attributes(grib_dumper* d, grib_accessor* a, const char* prefix)
 {
-    int i                           = 0;
+    int i = 0;
     grib_dumper_bufr_encode_C* self = (grib_dumper_bufr_encode_C*)d;
     unsigned long flags;
-    while (i < MAX_ACCESSOR_ATTRIBUTES && a->attributes[i]) {
+    while (i < MAX_ACCESSOR_ATTRIBUTES && a->attributes_[i]) {
         self->isAttribute = 1;
-        if ((d->option_flags & GRIB_DUMP_FLAG_ALL_ATTRIBUTES) == 0 && (a->attributes[i]->flags & GRIB_ACCESSOR_FLAG_DUMP) == 0) {
+        if ((d->option_flags & GRIB_DUMP_FLAG_ALL_ATTRIBUTES) == 0 && (a->attributes_[i]->flags_ & GRIB_ACCESSOR_FLAG_DUMP) == 0) {
             i++;
             continue;
         }
-        self->isLeaf = a->attributes[i]->attributes[0] == NULL ? 1 : 0;
-        flags        = a->attributes[i]->flags;
-        a->attributes[i]->flags |= GRIB_ACCESSOR_FLAG_DUMP;
-        switch (grib_accessor_get_native_type(a->attributes[i])) {
+        self->isLeaf = a->attributes_[i]->attributes_[0] == NULL ? 1 : 0;
+        flags        = a->attributes_[i]->flags_;
+        a->attributes_[i]->flags_ |= GRIB_ACCESSOR_FLAG_DUMP;
+        switch (a->attributes_[i]->get_native_type()) {
             case GRIB_TYPE_LONG:
-                dump_long_attribute(d, a->attributes[i], prefix);
+                dump_long_attribute(d, a->attributes_[i], prefix);
                 break;
             case GRIB_TYPE_DOUBLE:
-                dump_values_attribute(d, a->attributes[i], prefix);
+                dump_values_attribute(d, a->attributes_[i], prefix);
                 break;
             case GRIB_TYPE_STRING:
                 break;
         }
-        a->attributes[i]->flags = flags;
+        a->attributes_[i]->flags_ = flags;
         i++;
     }
     self->isLeaf      = 0;
@@ -844,7 +853,7 @@ static void dump_attributes(grib_dumper* d, grib_accessor* a, const char* prefix
 static void header(grib_dumper* d, grib_handle* h)
 {
     grib_dumper_bufr_encode_C* self = (grib_dumper_bufr_encode_C*)d;
-    char sampleName[200]            = { 0 };
+    char sampleName[200] = { 0 };
     long localSectionPresent, edition, bufrHeaderCentre, isSatellite;
 
     Assert(h->product_kind == PRODUCT_BUFR);
