@@ -138,10 +138,10 @@ static void dump_values(grib_dumper* d, grib_accessor* a)
     int i, r;
     int cols        = 9;
     long count      = 0;
-    grib_context* c = a->context;
+    grib_context* c = a->context_;
     grib_handle* h  = grib_handle_of_accessor(a);
 
-    if ((a->flags & GRIB_ACCESSOR_FLAG_DUMP) == 0 || (a->flags & GRIB_ACCESSOR_FLAG_READ_ONLY) != 0)
+    if ((a->flags_ & GRIB_ACCESSOR_FLAG_DUMP) == 0 || (a->flags_ & GRIB_ACCESSOR_FLAG_READ_ONLY) != 0)
         return;
 
     a->value_count(&count);
@@ -162,10 +162,10 @@ static void dump_values(grib_dumper* d, grib_accessor* a)
     if (size > 1) {
         int icount = 0;
 
-        if ((r = compute_bufr_key_rank(h, self->keys, a->name)) != 0)
-            fprintf(self->dumper.out, "set #%d#%s=", r, a->name);
+        if ((r = compute_bufr_key_rank(h, self->keys, a->name_)) != 0)
+            fprintf(self->dumper.out, "set #%d#%s=", r, a->name_);
         else
-            fprintf(self->dumper.out, "set %s=", a->name);
+            fprintf(self->dumper.out, "set %s=", a->name_);
 
         fprintf(self->dumper.out, "{");
 
@@ -187,12 +187,12 @@ static void dump_values(grib_dumper* d, grib_accessor* a)
         grib_context_free(c, values);
     }
     else {
-        r = compute_bufr_key_rank(h, self->keys, a->name);
+        r = compute_bufr_key_rank(h, self->keys, a->name_);
         if (!grib_is_missing_double(a, value)) {
             if (r != 0)
-                fprintf(self->dumper.out, "set #%d#%s=", r, a->name);
+                fprintf(self->dumper.out, "set #%d#%s=", r, a->name_);
             else
-                fprintf(self->dumper.out, "set %s=", a->name);
+                fprintf(self->dumper.out, "set %s=", a->name_);
 
             fprintf(self->dumper.out, "%.18e;\n", value);
         }
@@ -203,12 +203,12 @@ static void dump_values(grib_dumper* d, grib_accessor* a)
         int dofree = 0;
 
         if (r != 0) {
-            prefix = (char*)grib_context_malloc_clear(c, sizeof(char) * (strlen(a->name) + 10));
+            prefix = (char*)grib_context_malloc_clear(c, sizeof(char) * (strlen(a->name_) + 10));
             dofree = 1;
-            snprintf(prefix, 1024, "#%d#%s", r, a->name);
+            snprintf(prefix, 1024, "#%d#%s", r, a->name_);
         }
         else
-            prefix = (char*)a->name;
+            prefix = (char*)a->name_;
 
         dump_attributes(d, a, prefix);
         if (dofree)
@@ -229,9 +229,9 @@ static void dump_values_attribute(grib_dumper* d, grib_accessor* a, const char*
     int i, icount;
     int cols        = 2;
     long count      = 0;
-    grib_context* c = a->context;
+    grib_context* c = a->context_;
 
-    if ((a->flags & GRIB_ACCESSOR_FLAG_DUMP) == 0 || (a->flags & GRIB_ACCESSOR_FLAG_READ_ONLY) != 0)
+    if ((a->flags_ & GRIB_ACCESSOR_FLAG_DUMP) == 0 || (a->flags_ & GRIB_ACCESSOR_FLAG_READ_ONLY) != 0)
         return;
 
     a->value_count(&count);
@@ -249,7 +249,7 @@ static void dump_values_attribute(grib_dumper* d, grib_accessor* a, const char*
     self->empty = 0;
 
     if (size > 1) {
-        fprintf(self->dumper.out, "set %s->%s = {", prefix, a->name);
+        fprintf(self->dumper.out, "set %s->%s = {", prefix, a->name_);
         icount = 0;
         for (i = 0; i < size - 1; ++i) {
             if (icount > cols || i == 0) {
@@ -269,17 +269,17 @@ static void dump_values_attribute(grib_dumper* d, grib_accessor* a, const char*
         grib_context_free(c, values);
     }
     else {
-        /* int r=compute_bufr_key_rank(h,self->keys,a->name); */
+        /* int r=compute_bufr_key_rank(h,self->keys,a->name_); */
         if (!grib_is_missing_double(a, value)) {
-            fprintf(self->dumper.out, "set %s->%s = %.18e;\n", prefix, a->name, value);
+            fprintf(self->dumper.out, "set %s->%s = %.18e;\n", prefix, a->name_, value);
         }
     }
 
     if (self->isLeaf == 0) {
         char* prefix1;
 
-        prefix1 = (char*)grib_context_malloc_clear(c, sizeof(char) * (strlen(a->name) + strlen(prefix) + 5));
-        snprintf(prefix1, 1024, "%s->%s", prefix, a->name);
+        prefix1 = (char*)grib_context_malloc_clear(c, sizeof(char) * (strlen(a->name_) + strlen(prefix) + 5));
+        snprintf(prefix1, 1024, "%s->%s", prefix, a->name_);
 
         dump_attributes(d, a, prefix1);
 
@@ -300,28 +300,28 @@ static void dump_long(grib_dumper* d, grib_accessor* a, const char* comment)
     int i, r, icount;
     int cols        = 9;
     long count      = 0;
-    grib_context* c = a->context;
+    grib_context* c = a->context_;
     grib_handle* h  = grib_handle_of_accessor(a);
 
-    if ((a->flags & GRIB_ACCESSOR_FLAG_DUMP) == 0)
+    if ((a->flags_ & GRIB_ACCESSOR_FLAG_DUMP) == 0)
         return;
 
     a->value_count(&count);
     size = size2 = count;
 
-    if ((a->flags & GRIB_ACCESSOR_FLAG_READ_ONLY) != 0) {
+    if ((a->flags_ & GRIB_ACCESSOR_FLAG_READ_ONLY) != 0) {
         if (self->isLeaf == 0) {
             char* prefix;
             int dofree = 0;
 
-            r = compute_bufr_key_rank(h, self->keys, a->name);
+            r = compute_bufr_key_rank(h, self->keys, a->name_);
             if (r != 0) {
-                prefix = (char*)grib_context_malloc_clear(c, sizeof(char) * (strlen(a->name) + 10));
+                prefix = (char*)grib_context_malloc_clear(c, sizeof(char) * (strlen(a->name_) + 10));
                 dofree = 1;
-                snprintf(prefix, 1024, "#%d#%s", r, a->name);
+                snprintf(prefix, 1024, "#%d#%s", r, a->name_);
             }
             else
-                prefix = (char*)a->name;
+                prefix = (char*)a->name_;
 
             dump_attributes(d, a, prefix);
             if (dofree)
@@ -332,7 +332,7 @@ static void dump_long(grib_dumper* d, grib_accessor* a, const char* comment)
     }
 
     if (size > 1) {
-        values = (long*)grib_context_malloc_clear(a->context, sizeof(long) * size);
+        values = (long*)grib_context_malloc_clear(a->context_, sizeof(long) * size);
         err    = a->unpack_long(values, &size2);
     }
     else {
@@ -345,10 +345,10 @@ static void dump_long(grib_dumper* d, grib_accessor* a, const char* comment)
 
     if (size > 1) {
         icount = 0;
-        if ((r = compute_bufr_key_rank(h, self->keys, a->name)) != 0)
-            fprintf(self->dumper.out, "set #%d#%s=", r, a->name);
+        if ((r = compute_bufr_key_rank(h, self->keys, a->name_)) != 0)
+            fprintf(self->dumper.out, "set #%d#%s=", r, a->name_);
         else
-            fprintf(self->dumper.out, "set %s=", a->name);
+            fprintf(self->dumper.out, "set %s=", a->name_);
 
         fprintf(self->dumper.out, "{");
 
@@ -367,15 +367,15 @@ static void dump_long(grib_dumper* d, grib_accessor* a, const char* comment)
 
         depth -= 2;
         fprintf(self->dumper.out, "};\n");
-        grib_context_free(a->context, values);
+        grib_context_free(a->context_, values);
     }
     else {
-        r = compute_bufr_key_rank(h, self->keys, a->name);
+        r = compute_bufr_key_rank(h, self->keys, a->name_);
         if (!grib_is_missing_long(a, value)) {
             if (r != 0)
-                fprintf(self->dumper.out, "set #%d#%s=", r, a->name);
+                fprintf(self->dumper.out, "set #%d#%s=", r, a->name_);
             else
-                fprintf(self->dumper.out, "set %s=", a->name);
+                fprintf(self->dumper.out, "set %s=", a->name_);
 
             fprintf(self->dumper.out, "%ld;\n", value);
         }
@@ -386,12 +386,12 @@ static void dump_long(grib_dumper* d, grib_accessor* a, const char* comment)
         int dofree = 0;
 
         if (r != 0) {
-            prefix = (char*)grib_context_malloc_clear(c, sizeof(char) * (strlen(a->name) + 10));
+            prefix = (char*)grib_context_malloc_clear(c, sizeof(char) * (strlen(a->name_) + 10));
             dofree = 1;
-            snprintf(prefix, 1024, "#%d#%s", r, a->name);
+            snprintf(prefix, 1024, "#%d#%s", r, a->name_);
         }
         else
-            prefix = (char*)a->name;
+            prefix = (char*)a->name_;
 
         dump_attributes(d, a, prefix);
         if (dofree)
@@ -411,16 +411,16 @@ static void dump_long_attribute(grib_dumper* d, grib_accessor* a, const char* pr
     int i, icount;
     int cols        = 4;
     long count      = 0;
-    grib_context* c = a->context;
+    grib_context* c = a->context_;
 
-    if ((a->flags & GRIB_ACCESSOR_FLAG_DUMP) == 0 || (a->flags & GRIB_ACCESSOR_FLAG_READ_ONLY) != 0)
+    if ((a->flags_ & GRIB_ACCESSOR_FLAG_DUMP) == 0 || (a->flags_ & GRIB_ACCESSOR_FLAG_READ_ONLY) != 0)
         return;
 
     a->value_count(&count);
     size = size2 = count;
 
     if (size > 1) {
-        values = (long*)grib_context_malloc_clear(a->context, sizeof(long) * size);
+        values = (long*)grib_context_malloc_clear(a->context_, sizeof(long) * size);
         err    = a->unpack_long(values, &size2);
     }
     else {
@@ -431,7 +431,7 @@ static void dump_long_attribute(grib_dumper* d, grib_accessor* a, const char* pr
     self->empty = 0;
 
     if (size > 1) {
-        fprintf(self->dumper.out, "set %s->%s = {", prefix, a->name);
+        fprintf(self->dumper.out, "set %s->%s = {", prefix, a->name_);
         icount = 0;
         for (i = 0; i < size - 1; i++) {
             if (icount > cols || i == 0) {
@@ -447,13 +447,13 @@ static void dump_long_attribute(grib_dumper* d, grib_accessor* a, const char* pr
         fprintf(self->dumper.out, "%ld ", values[i]);
         depth -= 2;
         fprintf(self->dumper.out, "};\n");
-        grib_context_free(a->context, values);
+        grib_context_free(a->context_, values);
     }
     else {
-        /* int r=compute_bufr_key_rank(h,self->keys,a->name); */
+        /* int r=compute_bufr_key_rank(h,self->keys,a->name_); */
         if (!codes_bufr_key_exclude_from_dump(prefix)) {
             if (!grib_is_missing_long(a, value)) {
-                fprintf(self->dumper.out, "set %s->%s = ", prefix, a->name);
+                fprintf(self->dumper.out, "set %s->%s = ", prefix, a->name_);
                 fprintf(self->dumper.out, "%ld ;\n", value);
             }
         }
@@ -462,8 +462,8 @@ static void dump_long_attribute(grib_dumper* d, grib_accessor* a, const char* pr
     if (self->isLeaf == 0) {
         char* prefix1;
 
-        prefix1 = (char*)grib_context_malloc_clear(c, sizeof(char) * (strlen(a->name) + strlen(prefix) + 5));
-        snprintf(prefix1, 1024, "%s->%s", prefix, a->name);
+        prefix1 = (char*)grib_context_malloc_clear(c, sizeof(char) * (strlen(a->name_) + strlen(prefix) + 5));
+        snprintf(prefix1, 1024, "%s->%s", prefix, a->name_);
 
         dump_attributes(d, a, prefix1);
 
@@ -486,19 +486,19 @@ static void dump_double(grib_dumper* d, grib_accessor* a, const char* comment)
     grib_handle* h  = grib_handle_of_accessor(a);
     grib_context* c = h->context;
 
-    if ((a->flags & GRIB_ACCESSOR_FLAG_DUMP) == 0 || (a->flags & GRIB_ACCESSOR_FLAG_READ_ONLY) != 0)
+    if ((a->flags_ & GRIB_ACCESSOR_FLAG_DUMP) == 0 || (a->flags_ & GRIB_ACCESSOR_FLAG_READ_ONLY) != 0)
         return;
 
     a->unpack_double(&value, &size);
     self->begin = 0;
     self->empty = 0;
 
-    r = compute_bufr_key_rank(h, self->keys, a->name);
+    r = compute_bufr_key_rank(h, self->keys, a->name_);
     if (!grib_is_missing_double(a, value)) {
         if (r != 0)
-            fprintf(self->dumper.out, "set #%d#%s=", r, a->name);
+            fprintf(self->dumper.out, "set #%d#%s=", r, a->name_);
         else
-            fprintf(self->dumper.out, "set %s=", a->name);
+            fprintf(self->dumper.out, "set %s=", a->name_);
 
         fprintf(self->dumper.out, "%.18e;\n", value);
     }
@@ -508,12 +508,12 @@ static void dump_double(grib_dumper* d, grib_accessor* a, const char* comment)
         int dofree = 0;
 
         if (r != 0) {
-            prefix = (char*)grib_context_malloc_clear(c, sizeof(char) * (strlen(a->name) + 10));
+            prefix = (char*)grib_context_malloc_clear(c, sizeof(char) * (strlen(a->name_) + 10));
             dofree = 1;
-            snprintf(prefix, 1024, "#%d#%s", r, a->name);
+            snprintf(prefix, 1024, "#%d#%s", r, a->name_);
         }
         else
-            prefix = (char*)a->name;
+            prefix = (char*)a->name_;
 
         dump_attributes(d, a, prefix);
         if (dofree)
@@ -533,9 +533,9 @@ static void dump_string_array(grib_dumper* d, grib_accessor* a, const char* comm
     int r           = 0;
     grib_handle* h  = grib_handle_of_accessor(a);
 
-    c = a->context;
+    c = a->context_;
 
-    if ((a->flags & GRIB_ACCESSOR_FLAG_DUMP) == 0 || (a->flags & GRIB_ACCESSOR_FLAG_READ_ONLY) != 0)
+    if ((a->flags_ & GRIB_ACCESSOR_FLAG_DUMP) == 0 || (a->flags_ & GRIB_ACCESSOR_FLAG_READ_ONLY) != 0)
         return;
 
     a->value_count(&count);
@@ -549,10 +549,10 @@ static void dump_string_array(grib_dumper* d, grib_accessor* a, const char* comm
 
     if (self->isLeaf == 0) {
         depth += 2;
-        if ((r = compute_bufr_key_rank(h, self->keys, a->name)) != 0)
-            fprintf(self->dumper.out, "set #%d#%s=", r, a->name);
+        if ((r = compute_bufr_key_rank(h, self->keys, a->name_)) != 0)
+            fprintf(self->dumper.out, "set #%d#%s=", r, a->name_);
         else
-            fprintf(self->dumper.out, "set %s=", a->name);
+            fprintf(self->dumper.out, "set %s=", a->name_);
     }
 
     self->empty = 0;
@@ -581,12 +581,12 @@ static void dump_string_array(grib_dumper* d, grib_accessor* a, const char* comm
         int dofree = 0;
 
         if (r != 0) {
-            prefix = (char*)grib_context_malloc_clear(c, sizeof(char) * (strlen(a->name) + 10));
+            prefix = (char*)grib_context_malloc_clear(c, sizeof(char) * (strlen(a->name_) + 10));
             dofree = 1;
-            snprintf(prefix, 1024, "#%d#%s", r, a->name);
+            snprintf(prefix, 1024, "#%d#%s", r, a->name_);
         }
         else
-            prefix = (char*)a->name;
+            prefix = (char*)a->name_;
 
         dump_attributes(d, a, prefix);
         if (dofree)
@@ -604,11 +604,11 @@ static void dump_string(grib_dumper* d, grib_accessor* a, const char* comment)
     char* value                          = NULL;
     char* p                              = NULL;
     size_t size                          = 0;
-    grib_context* c                      = a->context;
+    grib_context* c                      = a->context_;
     int r = 0, err = 0;
     grib_handle* h = grib_handle_of_accessor(a);
 
-    if ((a->flags & GRIB_ACCESSOR_FLAG_DUMP) == 0 || (a->flags & GRIB_ACCESSOR_FLAG_READ_ONLY) != 0)
+    if ((a->flags_ & GRIB_ACCESSOR_FLAG_DUMP) == 0 || (a->flags_ & GRIB_ACCESSOR_FLAG_READ_ONLY) != 0)
         return;
 
     grib_get_string_length_acc(a, &size);
@@ -626,7 +626,7 @@ static void dump_string(grib_dumper* d, grib_accessor* a, const char* comment)
 
     err = a->unpack_string(value, &size);
     p   = value;
-    r   = compute_bufr_key_rank(h, self->keys, a->name);
+    r   = compute_bufr_key_rank(h, self->keys, a->name_);
     if (grib_is_missing_string(a, (unsigned char*)value, size)) {
         strcpy(value, ""); /* Empty string means MISSING string */
     }
@@ -642,9 +642,9 @@ static void dump_string(grib_dumper* d, grib_accessor* a, const char* comment)
     if (self->isLeaf == 0) {
         depth += 2;
         if (r != 0)
-            fprintf(self->dumper.out, "set #%d#%s=", r, a->name);
+            fprintf(self->dumper.out, "set #%d#%s=", r, a->name_);
         else
-            fprintf(self->dumper.out, "set %s=", a->name);
+            fprintf(self->dumper.out, "set %s=", a->name_);
     }
     fprintf(self->dumper.out, "\"%s\";\n", value);
 
@@ -654,12 +654,12 @@ static void dump_string(grib_dumper* d, grib_accessor* a, const char* comment)
         int dofree = 0;
 
         if (r != 0) {
-            prefix = (char*)grib_context_malloc_clear(c, sizeof(char) * (strlen(a->name) + 10));
+            prefix = (char*)grib_context_malloc_clear(c, sizeof(char) * (strlen(a->name_) + 10));
             dofree = 1;
-            snprintf(prefix, 1024, "#%d#%s", r, a->name);
+            snprintf(prefix, 1024, "#%d#%s", r, a->name_);
         }
         else
-            prefix = (char*)a->name;
+            prefix = (char*)a->name_;
 
         dump_attributes(d, a, prefix);
         if (dofree)
@@ -712,9 +712,9 @@ static void _dump_long_array(grib_handle* h, FILE* f, const char* key, const cha
 static void dump_section(grib_dumper* d, grib_accessor* a, grib_block_of_accessors* block)
 {
     grib_dumper_bufr_encode_filter* self = (grib_dumper_bufr_encode_filter*)d;
-    if (strcmp(a->name, "BUFR")==0 ||
-        strcmp(a->name, "GRIB")==0 ||
-        strcmp(a->name, "META")==0) {
+    if (strcmp(a->name_, "BUFR")==0 ||
+        strcmp(a->name_, "GRIB")==0 ||
+        strcmp(a->name_, "META")==0) {
         grib_handle* h = grib_handle_of_accessor(a);
         depth          = 2;
         self->begin    = 1;
@@ -728,8 +728,8 @@ static void dump_section(grib_dumper* d, grib_accessor* a, grib_block_of_accesso
         grib_dump_accessors_block(d, block);
         depth -= 2;
     }
-    else if (strcmp(a->name, "groupNumber")==0) {
-        if ((a->flags & GRIB_ACCESSOR_FLAG_DUMP) == 0)
+    else if (strcmp(a->name_, "groupNumber")==0) {
+        if ((a->flags_ & GRIB_ACCESSOR_FLAG_DUMP) == 0)
             return;
         self->begin = 1;
         self->empty = 1;
@@ -747,29 +747,29 @@ static void dump_attributes(grib_dumper* d, grib_accessor* a, const char* prefix
     int i                                = 0;
     grib_dumper_bufr_encode_filter* self = (grib_dumper_bufr_encode_filter*)d;
     unsigned long flags;
-    while (i < MAX_ACCESSOR_ATTRIBUTES && a->attributes[i]) {
+    while (i < MAX_ACCESSOR_ATTRIBUTES && a->attributes_[i]) {
         self->isAttribute = 1;
-        if ((d->option_flags & GRIB_DUMP_FLAG_ALL_ATTRIBUTES) == 0 && (a->attributes[i]->flags & GRIB_ACCESSOR_FLAG_DUMP) == 0) {
+        if ((d->option_flags & GRIB_DUMP_FLAG_ALL_ATTRIBUTES) == 0 && (a->attributes_[i]->flags_ & GRIB_ACCESSOR_FLAG_DUMP) == 0) {
             i++;
             continue;
         }
-        self->isLeaf = a->attributes[i]->attributes[0] == NULL ? 1 : 0;
+        self->isLeaf = a->attributes_[i]->attributes_[0] == NULL ? 1 : 0;
         /* fprintf(self->dumper.out,","); */
         /* fprintf(self->dumper.out,"\n%-*s",depth," "); */
-        /* fprintf(out,"\"%s\" : ",a->attributes[i]->name); */
-        flags = a->attributes[i]->flags;
-        a->attributes[i]->flags |= GRIB_ACCESSOR_FLAG_DUMP;
-        switch (a->attributes[i]->get_native_type()) {
+        /* fprintf(out,"\"%s\" : ",a->attributes_[i]->name); */
+        flags = a->attributes_[i]->flags_;
+        a->attributes_[i]->flags_ |= GRIB_ACCESSOR_FLAG_DUMP;
+        switch (a->attributes_[i]->get_native_type()) {
             case GRIB_TYPE_LONG:
-                dump_long_attribute(d, a->attributes[i], prefix);
+                dump_long_attribute(d, a->attributes_[i], prefix);
                 break;
             case GRIB_TYPE_DOUBLE:
-                dump_values_attribute(d, a->attributes[i], prefix);
+                dump_values_attribute(d, a->attributes_[i], prefix);
                 break;
             case GRIB_TYPE_STRING:
                 break;
         }
-        a->attributes[i]->flags = flags;
+        a->attributes_[i]->flags_ = flags;
         i++;
     }
     self->isLeaf      = 0;
